@@ -55,11 +55,13 @@ namespace FullWrtGraphInternal
 {
 ////////////////////////////////////////
 //! Internal: the sidebar of a FullWrtGraph
-struct SideBar : public FullWrtStruct::ZoneHeader {
+struct SideBar final : public FullWrtStruct::ZoneHeader {
   //! constructor
-  SideBar(FullWrtStruct::ZoneHeader const &header): FullWrtStruct::ZoneHeader(header), m_box(), m_page(0), m_borderId(0), m_parsed(false)
+  explicit SideBar(FullWrtStruct::ZoneHeader const &header): FullWrtStruct::ZoneHeader(header), m_box(), m_page(0), m_borderId(0), m_parsed(false)
   {
   }
+  //! destructor
+  ~SideBar() final;
   //! the position (in point)
   MWAWBox2f m_box;
   //! the page
@@ -70,16 +72,25 @@ struct SideBar : public FullWrtStruct::ZoneHeader {
   mutable bool m_parsed;
 };
 
+SideBar::~SideBar()
+{
+}
+
 ////////////////////////////////////////
 //! Internal: the state of a FullWrtGraph
 struct State {
   //! constructor
-  State() : m_version(-1), m_sidebarList(), m_graphicMap(), m_borderList(), m_numPages(-1) { }
+  State()
+    : m_version(-1)
+    , m_sidebarList()
+    , m_graphicMap()
+    , m_borderList()
+    , m_numPages(-1) { }
 
   //! the file version
   mutable int m_version;
   //! the sidebar list
-  std::vector<shared_ptr<SideBar> > m_sidebarList;
+  std::vector<std::shared_ptr<SideBar> > m_sidebarList;
   //! zoneId -> graphic entry
   std::multimap<int, FullWrtStruct::EntryPtr > m_graphicMap;
   //! a list of border
@@ -89,26 +100,24 @@ struct State {
 
 ////////////////////////////////////////
 //! Internal: the subdocument of a FullWrtGraph
-class SubDocument : public MWAWSubDocument
+class SubDocument final : public MWAWSubDocument
 {
 public:
   //! constructor
-  SubDocument(FullWrtGraph &pars, int id, MWAWColor fontColor) :
-    MWAWSubDocument(pars.m_mainParser, MWAWInputStreamPtr(), MWAWEntry()), m_graphParser(&pars), m_id(id), m_fontColor(fontColor) {}
+  SubDocument(FullWrtGraph &pars, int id, MWAWColor fontColor)
+    : MWAWSubDocument(pars.m_mainParser, MWAWInputStreamPtr(), MWAWEntry())
+    , m_graphParser(&pars)
+    , m_id(id)
+    , m_fontColor(fontColor) {}
 
   //! destructor
-  virtual ~SubDocument() {}
+  ~SubDocument() final {}
 
   //! operator!=
-  virtual bool operator!=(MWAWSubDocument const &doc) const;
-  //! operator!==
-  virtual bool operator==(MWAWSubDocument const &doc) const
-  {
-    return !operator!=(doc);
-  }
+  bool operator!=(MWAWSubDocument const &doc) const final;
 
   //! the parser function
-  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type);
+  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type) final;
 
 protected:
   /** the graph parser */
@@ -119,8 +128,8 @@ protected:
   MWAWColor m_fontColor;
 
 private:
-  SubDocument(SubDocument const &orig);
-  SubDocument &operator=(SubDocument const &orig);
+  SubDocument(SubDocument const &orig) = delete;
+  SubDocument &operator=(SubDocument const &orig) = delete;
 };
 
 void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*type*/)
@@ -139,7 +148,7 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*ty
 bool SubDocument::operator!=(MWAWSubDocument const &doc) const
 {
   if (MWAWSubDocument::operator!=(doc)) return true;
-  SubDocument const *sDoc = dynamic_cast<SubDocument const *>(&doc);
+  auto const *sDoc = dynamic_cast<SubDocument const *>(&doc);
   if (!sDoc) return true;
   if (m_graphParser != sDoc->m_graphParser) return true;
   if (m_id != sDoc->m_id) return true;
@@ -151,9 +160,10 @@ bool SubDocument::operator!=(MWAWSubDocument const &doc) const
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-FullWrtGraph::FullWrtGraph(FullWrtParser &parser) :
-  m_parserState(parser.getParserState()), m_state(new FullWrtGraphInternal::State),
-  m_mainParser(&parser)
+FullWrtGraph::FullWrtGraph(FullWrtParser &parser)
+  : m_parserState(parser.getParserState())
+  , m_state(new FullWrtGraphInternal::State)
+  , m_mainParser(&parser)
 {
 }
 
@@ -173,11 +183,11 @@ int FullWrtGraph::numPages() const
   if (m_state->m_numPages > 0)
     return m_state->m_numPages;
   int nPage=0;
-  for (size_t i=0; i<m_state->m_sidebarList.size(); ++i) {
-    if (!m_state->m_sidebarList[i])
+  for (auto sidebar : m_state->m_sidebarList) {
+    if (!sidebar)
       continue;
-    if (m_state->m_sidebarList[i]->m_page>nPage)
-      nPage=m_state->m_sidebarList[i]->m_page;
+    if (sidebar->m_page>nPage)
+      nPage=sidebar->m_page;
   }
   return (m_state->m_numPages=nPage);
 }
@@ -223,7 +233,7 @@ bool FullWrtGraph::readBorderDocInfo(FullWrtStruct::EntryPtr zone)
 
   long blckSz = input->readLong(4);
   long endData = pos+9+blckSz;
-  int num = (int) input->readULong(2);
+  auto num = static_cast<int>(input->readULong(2));
   int const fSz = 26;
   f << "Entries(Border):N=" << num << ",";
   if (blckSz < 2 || blckSz != 2 + num*fSz || endData > zone->end()) {
@@ -262,9 +272,9 @@ bool FullWrtGraph::readBorderDocInfo(FullWrtStruct::EntryPtr zone)
 
 ////////////////////////////////////////////////////////////
 // side bar
-shared_ptr<FullWrtStruct::ZoneHeader> FullWrtGraph::readSideBar(FullWrtStruct::EntryPtr zone, FullWrtStruct::ZoneHeader const &doc)
+std::shared_ptr<FullWrtStruct::ZoneHeader> FullWrtGraph::readSideBar(FullWrtStruct::EntryPtr zone, FullWrtStruct::ZoneHeader const &doc)
 {
-  shared_ptr<FullWrtGraphInternal::SideBar> sidebar;
+  std::shared_ptr<FullWrtGraphInternal::SideBar> sidebar;
   if (doc.m_type != 0x13 && doc.m_type != 0x14) {
     MWAW_DEBUG_MSG(("FullWrtGraph::readSideBar: find unexpected type\n"));
     return sidebar;
@@ -323,7 +333,7 @@ shared_ptr<FullWrtStruct::ZoneHeader> FullWrtGraph::readSideBar(FullWrtStruct::E
   val = int(input->readLong(1));
   if (val==1) {
     pos = input->tell();
-    long sz = (long) input->readULong(4);
+    auto sz = long(input->readULong(4));
     if (sz && input->tell()+sz <= zone->end()) {
       f.str("");
       f << "SideBar[end]:";
@@ -350,7 +360,7 @@ bool FullWrtGraph::readSideBarPosition(FullWrtStruct::EntryPtr zone, FullWrtGrap
   libmwaw::DebugFile &asciiFile = zone->getAsciiFile();
   libmwaw::DebugStream f;
 
-  long sz = (long) input->readULong(4);
+  auto sz = long(input->readULong(4));
   if (sz < 0 || pos+sz+4 > zone->end())
     return false;
   f << "SideBar[pos]:";
@@ -365,11 +375,10 @@ bool FullWrtGraph::readSideBarPosition(FullWrtStruct::EntryPtr zone, FullWrtGrap
   }
 
   int dim[4];
-  for (int i = 0; i < 4; i++)
-    dim[i]=int(input->readLong(2));
-  frame.m_box=MWAWBox2f(MWAWVec2i(dim[1],dim[0]),MWAWVec2i(dim[3],dim[2]));
+  for (auto &d : dim) d=int(input->readLong(2));
+  frame.m_box=MWAWBox2f(MWAWVec2f(float(dim[1]),float(dim[0])),MWAWVec2f(float(dim[3]),float(dim[2])));
   f << "pos=" << frame.m_box << ",";
-  int val=int(input->readLong(2));
+  auto val=int(input->readLong(2));
   if (val) f << "w[wrap]=" << val << "pt,";
   f << "ptr?=[" << std::hex;
   for (int i = 0; i < 2; i++) // two big number
@@ -383,7 +392,7 @@ bool FullWrtGraph::readSideBarPosition(FullWrtStruct::EntryPtr zone, FullWrtGrap
   if (frame.m_page) f << "page=" << frame.m_page << ",";
   val = int(input->readLong(2)); // number of point in the left part
   if (val) f << "N[left]?=" << val << ",";
-  int N=(int) input->readLong(2);
+  auto N=static_cast<int>(input->readLong(2));
   if (N*4+28 > sz) {
     f << "#N=" << N << ",";
     N=0;
@@ -397,8 +406,8 @@ bool FullWrtGraph::readSideBarPosition(FullWrtStruct::EntryPtr zone, FullWrtGrap
   */
   f << "mask=[";
   for (int i = 0; i < N; i++) {
-    int x = int(input->readLong(2));
-    int n = int(input->readLong(2));
+    auto x = int(input->readLong(2));
+    auto n = int(input->readLong(2));
     f << x << ":" << n << ",";
   }
   f << "],";
@@ -419,7 +428,7 @@ bool FullWrtGraph::readSideBarFormat(FullWrtStruct::EntryPtr zone, FullWrtGraphI
   libmwaw::DebugFile &asciiFile = zone->getAsciiFile();
   libmwaw::DebugStream f;
 
-  long sz = (long) input->readULong(4);
+  auto sz = long(input->readULong(4));
   if (sz < 0 || pos+sz+4 > zone->end())
     return false;
   f << "SideBar[format]:";
@@ -432,11 +441,11 @@ bool FullWrtGraph::readSideBarFormat(FullWrtStruct::EntryPtr zone, FullWrtGraphI
     return true;
   }
   f << "PTR=" << std::hex << input->readLong(4) << std::dec << ",";
-  int N=(int) input->readLong(1);
+  auto N=static_cast<int>(input->readLong(1));
   int val;
   if (N) {
     f << "N=" << N << ",";
-    val=(int) input->readLong(1);
+    val=static_cast<int>(input->readLong(1));
     if (val) f << "#f0=" << val << ",";
     /* now probably N*[unknData],
        find for N=1 005f000000b201d2001600f40f94020004100001009700000000000000000000
@@ -444,22 +453,21 @@ bool FullWrtGraph::readSideBarFormat(FullWrtStruct::EntryPtr zone, FullWrtGraphI
   }
   input->seek(pos+42, librevenge::RVNG_SEEK_SET);
   float dim[2];
-  for (int i=0; i < 2; ++i)
-    dim[i]=float(input->readLong(4))/65536.f;
+  for (auto &d : dim) d=float(input->readLong(4))/65536.f;
   f << "dim?=" << dim[1] << "x" << dim[0] << ",";
-  val=(int) input->readULong(2); // another dim with a flag?
+  val=static_cast<int>(input->readULong(2)); // another dim with a flag?
   if (val&0x8000) f << "f1[high],";
   if (val&0x7FFF) f << "f1=" << (val&0x7FFF) << ",";
   float w=float(input->readLong(4))/65536.f;
   f << "w[wrap]=" << w << "pt,";
-  frame.m_borderId=(int) input->readLong(2);
+  frame.m_borderId=static_cast<int>(input->readLong(2));
   if (frame.m_borderId)
     f << "B" << frame.m_borderId-1 << ",";
   if (vers==1) {
-    val=(int) input->readLong(2); // 0|1|4|b|20|..f0
+    val=static_cast<int>(input->readLong(2)); // 0|1|4|b|20|..f0
     if (val) f << "f2=" << val << ",";
   }
-  val=(int) input->readLong(2); // always 0
+  val=static_cast<int>(input->readLong(2)); // always 0
   if (val)
     f << "f3=" << val << ",";
 
@@ -479,7 +487,7 @@ bool FullWrtGraph::readSideBarUnknown(FullWrtStruct::EntryPtr zone, FullWrtGraph
   libmwaw::DebugFile &asciiFile = zone->getAsciiFile();
   libmwaw::DebugStream f;
 
-  long sz = (long) input->readULong(4);
+  auto sz = long(input->readULong(4));
   if (sz < 0 || pos+sz+4 > zone->end())
     return false;
   f << "SideBar[unknown]:";
@@ -491,22 +499,22 @@ bool FullWrtGraph::readSideBarUnknown(FullWrtStruct::EntryPtr zone, FullWrtGraph
     asciiFile.addNote(f.str().c_str());
     return true;
   }
-  int val = (int) input->readLong(2);
+  auto val = static_cast<int>(input->readLong(2));
   if (val!=-1)
     f << "f0=" << val << ",";
-  val = (int) input->readLong(2);
+  val = static_cast<int>(input->readLong(2));
   if (val!=1)
     f << "f1=" << val << ",";
-  val = (int) input->readULong(2); // maybe a color?
+  val = static_cast<int>(input->readULong(2)); // maybe a color?
   if (val)
     f << "f2=" << std::hex << val << std::dec << ",";
   for (int i=0; i<2; ++i) { // f3=1|2, f4=small numer 0..ff
-    val = (int) input->readULong(2);
+    val = static_cast<int>(input->readULong(2));
     if (val)
       f << "f" << i+3 << "=" << val << ",";
   }
   for (int i=0; i<19; ++i) { // g0,g1,g17,g18: in form xyxy, other 0
-    val = (int) input->readULong(2);
+    val = static_cast<int>(input->readULong(2));
     if (val)
       f << "g" << i << "=" << std::hex << val << std::dec << ",";
   }
@@ -545,9 +553,9 @@ bool FullWrtGraph::sendSideBar(FullWrtGraphInternal::SideBar const &frame)
 
 ////////////////////////////////////////////////////////////
 // graphic: data +
-shared_ptr<FullWrtStruct::ZoneHeader> FullWrtGraph::readGraphicData(FullWrtStruct::EntryPtr zone, FullWrtStruct::ZoneHeader &doc)
+std::shared_ptr<FullWrtStruct::ZoneHeader> FullWrtGraph::readGraphicData(FullWrtStruct::EntryPtr zone, FullWrtStruct::ZoneHeader &doc)
 {
-  shared_ptr<FullWrtStruct::ZoneHeader> graphData;
+  std::shared_ptr<FullWrtStruct::ZoneHeader> graphData;
   if (doc.m_type != 0x15) {
     MWAW_DEBUG_MSG(("FullWrtGraph::readGraphicData: find unexpected type\n"));
     return graphData;
@@ -578,11 +586,10 @@ shared_ptr<FullWrtStruct::ZoneHeader> FullWrtGraph::readGraphicData(FullWrtStruc
     f.str("");
     f << "GraphData[1]:";
     int dim[4];
-    for (int i = 0; i < 4; i++)
-      dim[i] = int(input->readLong(2));
+    for (auto &d : dim) d=int(input->readLong(2));
     f << "box=" << dim[1] << "x" << dim[0] << "<->" << dim[3] << "x" << dim[2] << ",";
     for (int i = 0; i < 2; i++) { // always 0 ?
-      int val = int(input->readLong(2));
+      auto val = int(input->readLong(2));
       if (val)
         f << "f" << i << "=" << val << "c";
     }
@@ -591,11 +598,11 @@ shared_ptr<FullWrtStruct::ZoneHeader> FullWrtGraph::readGraphicData(FullWrtStruc
   }
 
   f.str("");
-  int nextData = int(input->readULong(1));
+  auto nextData = int(input->readULong(1));
   pos = input->tell();
   if (nextData==1) {
     f << "GraphData[2]:";
-    long sz = (long) input->readULong(4);
+    auto sz = long(input->readULong(4));
     if (sz < 0 || pos+4+sz > zone->end()) {
       f << "#sz=" << sz << ",";
       input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -603,7 +610,7 @@ shared_ptr<FullWrtStruct::ZoneHeader> FullWrtGraph::readGraphicData(FullWrtStruc
     else if (sz) {   // a serie of doc id ( normally 1e )
       f << "docId[type1e?]=[";
       for (int i = 0; i < sz/2; i++) {
-        int id = int(input->readLong(2));
+        auto id = int(input->readLong(2));
         std::string type=m_mainParser->getDocumentTypeName(id);
         if (type.empty())
           f << "#" << id << ",";
@@ -635,7 +642,7 @@ bool FullWrtGraph::readGraphic(FullWrtStruct::EntryPtr zone)
 
   long pos = zone->begin();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
-  long sz = (long) input->readULong(4);
+  auto sz = long(input->readULong(4));
   int expectedSz = vers==1 ? 0x5c : 0x54;
   if (sz != expectedSz || pos+sz > zone->end()) return false;
   input->seek(sz, librevenge::RVNG_SEEK_CUR);
@@ -647,7 +654,7 @@ bool FullWrtGraph::readGraphic(FullWrtStruct::EntryPtr zone)
   asciiFile.addNote(f.str().c_str());
 
   pos = input->tell();
-  sz = (long) input->readULong(4);
+  sz = long(input->readULong(4));
   if (!sz || pos+4+sz > zone->end()) {
     MWAW_DEBUG_MSG(("FullWrtGraph::readGraphic: can not read graphic size\n"));
     return false;
@@ -666,7 +673,7 @@ bool FullWrtGraph::readGraphic(FullWrtStruct::EntryPtr zone)
   if (pos == zone->end())
     return true;
 
-  sz = (long)input->readULong(4);
+  sz = long(input->readULong(4));
   if (sz)
     input->seek(sz, librevenge::RVNG_SEEK_CUR);
   if (pos+4+sz!=zone->end()) {
@@ -686,14 +693,12 @@ bool FullWrtGraph::readGraphic(FullWrtStruct::EntryPtr zone)
 ////////////////////////////////////////////////////////////
 bool FullWrtGraph::sendGraphic(int fId)
 {
-  std::multimap<int, FullWrtStruct::EntryPtr >::iterator it =
-    m_state->m_graphicMap.find(fId);
-
+  auto it = m_state->m_graphicMap.find(fId);
   if (it == m_state->m_graphicMap.end() || !it->second) {
     MWAW_DEBUG_MSG(("FullWrtGraph::sendGraphic: can not find graphic %d\n", fId));
     return false;
   }
-  FullWrtStruct::EntryPtr zone = it->second;
+  auto zone = it->second;
   MWAWInputStreamPtr input = zone->m_input;
   long pos = input->tell();
   bool ok=sendGraphic(zone);
@@ -714,12 +719,12 @@ bool FullWrtGraph::sendGraphic(FullWrtStruct::EntryPtr zone)
 
   long pos = zone->begin();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
-  int sz = (int)input->readULong(4);
+  auto sz = static_cast<int>(input->readULong(4));
   input->seek(sz, librevenge::RVNG_SEEK_CUR);
 
   // header
   pos = input->tell();
-  sz = (int)input->readULong(4);
+  sz = static_cast<int>(input->readULong(4));
 
 #ifdef DEBUG_WITH_FILES
   if (1) {
@@ -735,8 +740,7 @@ bool FullWrtGraph::sendGraphic(FullWrtStruct::EntryPtr zone)
 
   input->seek(pos+4, librevenge::RVNG_SEEK_SET);
   MWAWBox2f box;
-  MWAWPict::ReadResult res =
-    MWAWPictData::check(input, sz, box);
+  auto res = MWAWPictData::check(input, sz, box);
   if (res == MWAWPict::MWAW_R_BAD) {
     MWAW_DEBUG_MSG(("FullWrtGraph::sendGraphic: can not find the picture\n"));
     return false;
@@ -755,8 +759,7 @@ bool FullWrtGraph::sendGraphic(FullWrtStruct::EntryPtr zone)
   pictPos.setNaturalSize(naturalSize);
 
   input->seek(pos+4, librevenge::RVNG_SEEK_SET);
-  shared_ptr<MWAWPict> pict
-  (MWAWPictData::get(input, sz));
+  std::shared_ptr<MWAWPict> pict(MWAWPictData::get(input, sz));
   if (pict) {
     MWAWEmbeddedObject picture;
     if (pict->getBinary(picture)) {
@@ -770,21 +773,19 @@ bool FullWrtGraph::sendGraphic(FullWrtStruct::EntryPtr zone)
 
 bool FullWrtGraph::sendPageGraphics()
 {
-  for (size_t i=0; i<m_state->m_sidebarList.size(); ++i) {
-    if (!m_state->m_sidebarList[i])
+  for (auto const &frame : m_state->m_sidebarList) {
+    if (!frame)
       continue;
-    FullWrtGraphInternal::SideBar const &frame=*m_state->m_sidebarList[i];
-    if (!frame.m_parsed)
-      sendSideBar(frame);
+    if (!frame->m_parsed)
+      sendSideBar(*frame);
   }
   return true;
 }
 
 void FullWrtGraph::flushExtra()
 {
-  std::multimap<int, FullWrtStruct::EntryPtr >::iterator it;
-  for (it = m_state->m_graphicMap.begin(); it != m_state->m_graphicMap.end(); ++it) {
-    FullWrtStruct::EntryPtr &zone = it->second;
+  for (auto it : m_state->m_graphicMap) {
+    FullWrtStruct::EntryPtr &zone = it.second;
     if (!zone || zone->isParsed())
       continue;
     sendGraphic(zone);
