@@ -65,9 +65,16 @@ namespace HanMacWrdJParserInternal
 //! Internal: the state of a HanMacWrdJParser
 struct State {
   //! constructor
-  State() : m_zonesListBegin(-1), m_zonesMap(), m_zonesIdList(),
-    m_actPage(0), m_numPages(0), m_headerHeight(0), m_footerHeight(0),
-    m_headerId(0), m_footerId(0)
+  State()
+    : m_zonesListBegin(-1)
+    , m_zonesMap()
+    , m_zonesIdList()
+    , m_actPage(0)
+    , m_numPages(0)
+    , m_headerHeight(0)
+    , m_footerHeight(0)
+    , m_headerId(0)
+    , m_footerId(0)
   {
   }
 
@@ -89,31 +96,26 @@ struct State {
 
 ////////////////////////////////////////
 //! Internal: the subdocument of a HanMacWrdJParser
-class SubDocument : public MWAWSubDocument
+class SubDocument final : public MWAWSubDocument
 {
 public:
-  SubDocument(HanMacWrdJParser &pars, MWAWInputStreamPtr input, long zoneId) :
-    MWAWSubDocument(&pars, input, MWAWEntry()), m_id(zoneId) {}
+  SubDocument(HanMacWrdJParser &pars, MWAWInputStreamPtr const &input, long zoneId)
+    : MWAWSubDocument(&pars, input, MWAWEntry())
+    , m_id(zoneId) {}
 
   //! destructor
-  virtual ~SubDocument() {}
+  ~SubDocument() final {}
 
   //! operator!=
-  virtual bool operator!=(MWAWSubDocument const &doc) const
+  bool operator!=(MWAWSubDocument const &doc) const final
   {
     if (MWAWSubDocument::operator!=(doc)) return true;
-    SubDocument const *sDoc = dynamic_cast<SubDocument const *>(&doc);
+    auto const *sDoc = dynamic_cast<SubDocument const *>(&doc);
     if (!sDoc) return true;
     if (m_id != sDoc->m_id) return true;
     return false;
   }
 
-  //! operator!==
-  virtual bool operator==(MWAWSubDocument const &doc) const
-  {
-    return !operator!=(doc);
-  }
-
   //! returns the subdocument \a id
   long getId() const
   {
@@ -126,7 +128,7 @@ public:
   }
 
   //! the parser function
-  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type);
+  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type) final;
 
 protected:
   //! the subdocument id
@@ -143,7 +145,7 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type
     MWAW_DEBUG_MSG(("HanMacWrdJParserInternal::SubDocument::parse: unexpected document type\n"));
     return;
   }
-  HanMacWrdJParser *parser=dynamic_cast<HanMacWrdJParser *>(m_parser);
+  auto *parser=dynamic_cast<HanMacWrdJParser *>(m_parser);
   if (!parser) {
     MWAW_DEBUG_MSG(("HanMacWrdJParserInternal::SubDocument::parse: no parser\n"));
     return;
@@ -158,8 +160,11 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type
 ////////////////////////////////////////////////////////////
 // constructor/destructor + basic interface ...
 ////////////////////////////////////////////////////////////
-HanMacWrdJParser::HanMacWrdJParser(MWAWInputStreamPtr input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header) :
-  MWAWTextParser(input, rsrcParser, header), m_state(), m_graphParser(), m_textParser()
+HanMacWrdJParser::HanMacWrdJParser(MWAWInputStreamPtr const &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
+  : MWAWTextParser(input, rsrcParser, header)
+  , m_state()
+  , m_graphParser()
+  , m_textParser()
 {
   init();
 }
@@ -194,7 +199,7 @@ bool HanMacWrdJParser::canSendTextAsGraphic(long id, long cPos)
 
 bool HanMacWrdJParser::sendZone(long zId)
 {
-  MWAWPosition pos(MWAWVec2i(0,0), MWAWVec2i(0,0), librevenge::RVNG_POINT);
+  MWAWPosition pos(MWAWVec2f(0,0), MWAWVec2f(0,0), librevenge::RVNG_POINT);
   pos.setRelativePosition(MWAWPosition::Char);
   return m_graphParser->sendFrame(zId, pos);
 }
@@ -255,14 +260,14 @@ bool HanMacWrdJParser::readClassicHeader(HanMacWrdJZoneHeader &header, long endP
 ////////////////////////////////////////////////////////////
 void HanMacWrdJParser::parse(librevenge::RVNGTextInterface *docInterface)
 {
-  if (!getInput().get() || !checkHeader(0L)) throw(libmwaw::ParseException());
+  if (!getInput().get() || !checkHeader(nullptr)) throw(libmwaw::ParseException());
   bool ok = true;
   try {
     // create the asciiFile
     ascii().setStream(getInput());
     ascii().open(asciiName());
 
-    checkHeader(0L);
+    checkHeader(nullptr);
     ok = createZones();
     if (ok) {
       createDocument(docInterface);
@@ -342,10 +347,9 @@ bool HanMacWrdJParser::createZones()
   m_state->m_zonesIdList.clear();
   m_state->m_zonesIdList.resize(16,0);
   /* some zones do not seem to appear in this list, so we must track them */
-  std::map<long,MWAWEntry>::iterator it;
   std::vector<MWAWEntry> newEntriesList;
-  for (it = m_state->m_zonesMap.begin()  ; it != m_state->m_zonesMap.end(); ++it) {
-    MWAWEntry const &entry = it->second;
+  for (auto it : m_state->m_zonesMap) {
+    auto const &entry=it.second;
     if (!entry.valid()) continue;
     if (m_state->m_zonesMap.find(entry.end()) != m_state->m_zonesMap.end())
       continue;
@@ -363,8 +367,7 @@ bool HanMacWrdJParser::createZones()
       newEntry.setBegin(newBeginPos);
     }
   }
-  for (size_t i=0; i < newEntriesList.size(); i++) {
-    MWAWEntry const &zone=newEntriesList[i];
+  for (MWAWEntry const &zone : newEntriesList) {
     if (!zone.valid())
       continue;
     m_state->m_zonesMap.insert
@@ -372,19 +375,18 @@ bool HanMacWrdJParser::createZones()
   }
 
   // now parse the different zones
-  for (it =  m_state->m_zonesMap.begin(); it != m_state->m_zonesMap.end(); ++it) {
-    if (it->second.begin()<=0) continue;
-    readZone(it->second);
+  for (auto &it : m_state->m_zonesMap) {
+    if (it.second.begin()<=0) continue;
+    readZone(it.second);
   }
 
   // retrieve the text type, look for header/footer and pass information to text parser
   std::map<long,int> idTypeMap = m_graphParser->getTextFrameInformations();
-  std::map<long,int>::const_iterator typeIt=idTypeMap.begin();
-  for (; typeIt!=idTypeMap.end() ; ++typeIt) {
-    if (typeIt->second==1)
-      m_state->m_headerId = typeIt->first;
-    else if (typeIt->second==2)
-      m_state->m_footerId = typeIt->first;
+  for (auto typeIt : idTypeMap) {
+    if (typeIt.second==1)
+      m_state->m_headerId = typeIt.first;
+    else if (typeIt.second==2)
+      m_state->m_footerId = typeIt.first;
   }
   m_textParser->updateTextZoneTypes(idTypeMap);
 
@@ -398,9 +400,9 @@ bool HanMacWrdJParser::createZones()
   m_graphParser->prepareStructures();
 
   libmwaw::DebugStream f;
-  for (it = m_state->m_zonesMap.begin(); it !=m_state->m_zonesMap.end(); ++it) {
-    if (it->second.begin()<=0) continue;
-    MWAWEntry const &zone = it->second;
+  for (auto it : m_state->m_zonesMap) {
+    MWAWEntry const &zone = it.second;
+    if (zone.begin()<=0) continue;
     if (zone.isParsed()) continue;
     f.str("");
     f << "Entries(" << zone.name() << "):";
@@ -424,9 +426,9 @@ bool HanMacWrdJParser::checkEntry(MWAWEntry &entry)
   long pos = input->tell();
   input->seek(entry.begin(), librevenge::RVNG_SEEK_SET);
 
-  int type = static_cast<int>(input->readULong(2));
+  auto type = static_cast<int>(input->readULong(2));
   long val = input->readLong(2); // always 0?
-  long length = long(input->readULong(4));
+  auto length = long(input->readULong(4));
   if (type >= 32 || length < 8 || !input->checkPosition(entry.begin()+length)) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return false;
@@ -467,7 +469,7 @@ bool HanMacWrdJParser::readZonesList()
   libmwaw::DebugStream f;
   f << "Entries(Zones):";
   for (int i = 0; i < 7; i++) { // f0=a000
-    long val = long(input->readULong(2));
+    auto val = long(input->readULong(2));
     if (val) f << "f" << i << "=" << std::hex << val << std::dec << ",";
   }
   ascii().addPos(pos);
@@ -479,7 +481,7 @@ bool HanMacWrdJParser::readZonesList()
 
   for (int i = 0; i < 20; i++) {
     // sure up to Zonesb=FontNames Zones19=EOF
-    long ptr = long(input->readULong(4));
+    auto ptr = long(input->readULong(4));
     if (!ptr) continue;
     if (!input->checkPosition(ptr))
       f << "###";
@@ -519,7 +521,7 @@ bool HanMacWrdJParser::readZone(MWAWEntry &entry)
   input->seek(pos, librevenge::RVNG_SEEK_SET);
 
   f << "Entries(" << entry.name() << "):";
-  int type = static_cast<int>(input->readULong(2)); // number between 0 and f
+  auto type = static_cast<int>(input->readULong(2)); // number between 0 and f
   f << "type=" << type << ",";
   long val = input->readLong(2);
   if (val) f << "f0=" << val << ",";
@@ -612,20 +614,20 @@ bool HanMacWrdJParser::readPrintInfo(MWAWEntry const &entry)
   entry.setParsed(true);
 
   f << "Entries(PrintInfo):";
-  float margins[4] = {0,0,0,0}; // L, T, R, B
-  int dim[4] = {0,0,0,0};
   long val;
 
   val = long(input->readULong(2));
   if (val != 1) f << "firstSectNumber=" << val << ",";
   val = long(input->readULong(2));
   if (val) f << "f0=" << val << ",";
-  for (int i = 0; i < 4; i++) dim[i]=int(input->readLong(2));
+  int dim[4] = {0,0,0,0};
+  for (auto &d : dim) d=int(input->readLong(2));
   f << "paper=[" << dim[1] << "x" << dim[0] << " " << dim[3] << "x" << dim[2] << "],";
   f << "margins?=[";
-  for (int i= 0; i < 4; i++) {
-    margins[i] = float(input->readLong(4))/65536.f;
-    f << margins[i] << ",";
+  float margins[4] = {0,0,0,0}; // L, T, R, B
+  for (auto &margin : margins) {
+    margin = float(input->readLong(4))/65536.f;
+    f << margin << ",";
   }
   f << "],";
 
@@ -661,7 +663,7 @@ bool HanMacWrdJParser::readPrintInfo(MWAWEntry const &entry)
     paperSize = MWAWVec2i(dim[3]-dim[1],dim[2]-dim[0]);
   else if (usePrintInfo) {
     lTopMargin= MWAWVec2f(-float(info.paper().pos(0)[0]), -float(info.paper().pos(0)[1]));
-    rBotMargin=info.paper().pos(1) - info.page().pos(1);
+    rBotMargin=MWAWVec2f(info.paper().pos(1) - info.page().pos(1));
 
     // move margin left | top
     float decalX = lTopMargin.x() > 14 ? 14 : 0;
@@ -742,7 +744,7 @@ bool HanMacWrdJParser::readZoneA(MWAWEntry const &entry)
   f << "listId=[" << std::hex;
   std::vector<long> listIds;
   for (int i = 0; i < mainHeader.m_n; i++) {
-    long val = long(input->readULong(4));
+    auto val = long(input->readULong(4));
     listIds.push_back(val);
     f << val << ",";
   }
@@ -768,7 +770,7 @@ bool HanMacWrdJParser::readZoneA(MWAWEntry const &entry)
       return true;
     f.str("");
     f << entry.name() << "-" << i << ":";
-    long dataSz = long(input->readULong(4));
+    auto dataSz = long(input->readULong(4));
     long zoneEnd=pos+4+dataSz;
 
     if (zoneEnd>endPos) {
@@ -855,7 +857,7 @@ bool HanMacWrdJParser::readZoneB(MWAWEntry const &entry)
     pos = input->tell();
     f.str("");
     f << entry.name() << "-" << i << ":";
-    long dataSz = long(input->readULong(4));
+    auto dataSz = long(input->readULong(4));
     if (pos+4+dataSz>endPos) {
       MWAW_DEBUG_MSG(("HanMacWrdJParser::readZoneB: can not read an entry\n"));
       f << "###sz=" << dataSz;
@@ -986,7 +988,7 @@ bool HanMacWrdJParser::readZoneWithHeader(MWAWEntry const &entry)
     pos = input->tell();
     f.str("");
     f << entry.name() << "-" << i << ":";
-    long dataSz = long(input->readULong(4));
+    auto dataSz = long(input->readULong(4));
     if (pos+4+dataSz>endPos) {
       MWAW_DEBUG_MSG(("HanMacWrdJParser::readZoneWithHeader: can not read an entry\n"));
       f << "###sz=" << dataSz;
@@ -1011,7 +1013,7 @@ bool HanMacWrdJParser::readZoneWithHeader(MWAWEntry const &entry)
       return true;
     f.str("");
     f << entry.name() << "-A" << i++ << ":";
-    long dataSz = long(input->readULong(4));
+    auto dataSz = long(input->readULong(4));
     if (pos+4+dataSz>endPos) {
       MWAW_DEBUG_MSG(("HanMacWrdJParser::readZoneWithHeader: can not read an entry\n"));
       f << "###sz=" << dataSz;
@@ -1046,11 +1048,10 @@ bool HanMacWrdJParser::checkHeader(MWAWHeader *header, bool strict)
   }
   input->seek(0,librevenge::RVNG_SEEK_SET);
   int head[3];
-  for (int i = 0; i < 3; i++)
-    head[i] = static_cast<int>(input->readULong(2));
+  for (auto &h : head) h = static_cast<int>(input->readULong(2));
   if (head[0] != 0x594c || head[1] != 0x5953 || head[2] != 0x100)
     return false;
-  int val = static_cast<int>(input->readLong(1));
+  auto val = static_cast<int>(input->readLong(1));
   if (val==1) f << "hasPassword,";
   else if (val) {
     if (strict) return false;
@@ -1092,7 +1093,7 @@ bool HanMacWrdJParser::checkHeader(MWAWHeader *header, bool strict)
       input->seek(pos+60, librevenge::RVNG_SEEK_SET);
       continue;
     }
-    int fSz = static_cast<int>(input->readULong(1));
+    auto fSz = static_cast<int>(input->readULong(1));
     if (fSz >= fieldSizes[i]) {
       if (strict)
         return false;
