@@ -54,7 +54,8 @@ namespace MWAWGraphicEncoderInternal
 //! the state of a MWAWGraphicEncoder
 struct State {
   //! constructor
-  State() : m_encoder()
+  State()
+    : m_encoder()
   {
   }
   //! the encoder
@@ -63,7 +64,9 @@ struct State {
 
 }
 
-MWAWGraphicEncoder::MWAWGraphicEncoder() : librevenge::RVNGDrawingInterface(), m_state(new MWAWGraphicEncoderInternal::State)
+MWAWGraphicEncoder::MWAWGraphicEncoder()
+  : librevenge::RVNGDrawingInterface()
+  , m_state(new MWAWGraphicEncoderInternal::State)
 {
 }
 
