@@ -46,10 +46,10 @@
 
 #include "MWAWHeader.hxx"
 
-MWAWHeader::MWAWHeader(MWAWDocument::Type documentType, int vers, MWAWDocument::Kind kind) :
-  m_version(vers),
-  m_docType(documentType),
-  m_docKind(kind)
+MWAWHeader::MWAWHeader(MWAWDocument::Type documentType, int vers, MWAWDocument::Kind kind)
+  : m_version(vers)
+  , m_docType(documentType)
+  , m_docKind(kind)
 {
 }
 
@@ -61,7 +61,7 @@ MWAWHeader::~MWAWHeader()
  * So far, we have identified
  */
 std::vector<MWAWHeader> MWAWHeader::constructHeader
-(MWAWInputStreamPtr input, shared_ptr<MWAWRSRCParser> /*rsrcParser*/)
+(MWAWInputStreamPtr input, std::shared_ptr<MWAWRSRCParser> /*rsrcParser*/)
 {
   std::vector<MWAWHeader> res;
   if (!input) return res;
@@ -550,8 +550,7 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
 
   input->seek(0, librevenge::RVNG_SEEK_SET);
   int val[5];
-  for (int i = 0; i < 5; i++)
-    val[i] = int(input->readULong(2));
+  for (auto &v : val) v = int(input->readULong(2));
 
   // ----------- clearly discriminant ------------------
   if (val[2] == 0x424F && val[3] == 0x424F && (val[0]>>8) < 7) {
@@ -588,7 +587,7 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
   }
   if (val[0]==0x5772 && val[1]==0x6974 && val[2]==0x654e && val[3]==0x6f77) {
     input->seek(8, librevenge::RVNG_SEEK_SET);
-    int version = int(input->readLong(2));
+    auto version = int(input->readLong(2));
 
 #ifdef DEBUG
     bool ok = (version >= 0 && version <= 3);
@@ -755,7 +754,7 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
       res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MICROSOFTWORKS, 4));
     else if (mainOle && mainOle->size()>18) {
       mainOle->seek(16, librevenge::RVNG_SEEK_SET);
-      int value=static_cast<int>(mainOle->readULong(2));
+      auto value=static_cast<int>(mainOle->readULong(2));
       switch (value) {
       case 2:
         res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MICROSOFTWORKS, 4, MWAWDocument::MWAW_K_DATABASE));
@@ -840,7 +839,7 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
   // ----------- other ------------------
   if (val[0]==0 && val[1]==0 && val[2]==0 && val[3]==0) {
     input->seek(8, librevenge::RVNG_SEEK_SET);
-    int value=static_cast<int>(input->readULong(1));
+    auto value=static_cast<int>(input->readULong(1));
     if (value==0x4 || value==0x44) {
       MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a WriteNow 1.0 or 2.0 file\n"));
       res.push_back(MWAWHeader(MWAWDocument::MWAW_T_WRITENOW, 2));
@@ -873,7 +872,7 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
     }
     if (vers > 0 && input->size()>16) {
       input->seek(16, librevenge::RVNG_SEEK_SET);
-      int value=static_cast<int>(input->readULong(2));
+      auto value=static_cast<int>(input->readULong(2));
       switch (value) {
       case 1:
         res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MICROSOFTWORKS, vers));
@@ -905,7 +904,7 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
   }
   if (val[0] == 0x1000) {
     input->seek(10, librevenge::RVNG_SEEK_SET);
-    int value=static_cast<int>(input->readULong(2));
+    auto value=static_cast<int>(input->readULong(2));
     // 1: bitmap, 2: vectorized graphic
     if (value==1)
       res.push_back(MWAWHeader(MWAWDocument::MWAW_T_SUPERPAINT, 1, MWAWDocument::MWAW_K_PAINT));
@@ -924,7 +923,7 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
       bool ok=true;
       int numSlash=0;
       for (int i=0; i<sSz; ++i) {
-        char c=char(input->readULong(1));
+        auto c=char(input->readULong(1));
         if (c>='0' && c<='9')
           continue;
         if (c=='/')
@@ -946,7 +945,7 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
     if (!input->checkPosition(512*st+13))
       break;
     input->seek(512*st+10, librevenge::RVNG_SEEK_SET);
-    int value=static_cast<int>(input->readULong(2));
+    auto value=static_cast<int>(input->readULong(2));
     if (value==0x1101) {
       res.push_back(MWAWHeader(MWAWDocument::MWAW_T_APPLEPICT, 1, MWAWDocument::MWAW_K_DRAW));
       break;
@@ -972,9 +971,9 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
           ok=false;
           break;
         }
-        int wh=static_cast<int>(input->readULong(1));
+        auto wh=static_cast<int>(input->readULong(1));
         if (wh>=0x81) {
-          int color=static_cast<int>(input->readULong(1));
+          auto color=static_cast<int>(input->readULong(1));
           // consider that repeat color is anormal...
           if (col+(0x101-wh)>72 || (lastColor>=0 && color==lastColor)) {
             ok=false;
@@ -1005,8 +1004,7 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
   if (input->seek(-4, librevenge::RVNG_SEEK_END))
     return res;
   int lVal[2];
-  for (int i = 0; i < 2; i++)
-    lVal[i]=int(input->readULong(2));
+  for (auto &v : lVal) v=int(input->readULong(2));
   if (lVal[0] == 0x4E4C && lVal[1]==0x544F) // NLTO
     res.push_back(MWAWHeader(MWAWDocument::MWAW_T_ACTA, 2));
   else if (lVal[1]==0 && val[0]==1 && (val[1]==1||val[1]==2))
