@@ -65,11 +65,23 @@ namespace MacDraft5StyleManagerInternal
      must be used
  */
 struct Pixmap {
-  Pixmap() : m_rowBytes(0), m_rect(), m_version(-1), m_packType(0),
-    m_packSize(0), m_pixelType(0), m_pixelSize(0), m_compCount(0),
-    m_compSize(0), m_planeBytes(0), m_colorTable(), m_indices(), m_colors(), m_mode(0)
+  Pixmap()
+    : m_rowBytes(0)
+    , m_rect()
+    , m_version(-1)
+    , m_packType(0)
+    , m_packSize(0)
+    , m_pixelType(0)
+    , m_pixelSize(0)
+    , m_compCount(0)
+    , m_compSize(0)
+    , m_planeBytes(0)
+    , m_colorTable()
+    , m_indices()
+    , m_colors()
+    , m_mode(0)
   {
-    m_resolution[0] = m_resolution[1] = 0;
+    for (auto &res : m_resolution) res=0;
   }
 
   //! operator<< for Pixmap
@@ -89,7 +101,7 @@ struct Pixmap {
     int nBytes = 3, rowBytes = m_rowBytes;
     int numValuesByInt = 1;
     int maxValues = (1 << m_pixelSize)-1;
-    int numColors = (int) m_colorTable.size();
+    auto numColors = static_cast<int>(m_colorTable.size());
     int maxColorsIndex = -1;
 
     switch (m_pixelSize) {
@@ -132,7 +144,7 @@ struct Pixmap {
     }
 
     std::vector<unsigned char> values;
-    values.resize(size_t(m_rowBytes+24), (unsigned char)0);
+    values.resize(size_t(m_rowBytes+24), static_cast<unsigned char>(0));
 
     for (int y = 0; y < H; y++) {
       unsigned long numR = 0;
@@ -150,33 +162,33 @@ struct Pixmap {
       int wPos = y*W;
       if (m_pixelSize <= 8) { // indexed
         for (int x = 0, rPos = 0; x < W;) {
-          unsigned char val = values[(size_t)rPos++];
+          unsigned char val = values[size_t(rPos++)];
           for (int v = numValuesByInt-1; v >=0; v--) {
             int index = (val>>(v*m_pixelSize))&maxValues;
             if (index > maxColorsIndex) maxColorsIndex = index;
-            m_indices[(size_t)wPos++] = index;
+            m_indices[size_t(wPos++)] = index;
             if (++x >= W) break;
           }
         }
       }
       else if (m_pixelSize == 16) {
         for (int x = 0, rPos = 0; x < W; x++) {
-          unsigned int val = 256*(unsigned int)values[(size_t)rPos]+(unsigned int)values[(size_t)rPos+1];
+          unsigned int val = 256*static_cast<unsigned int>(values[size_t(rPos)])+static_cast<unsigned int>(values[size_t(rPos+1)]);
           rPos+=2;
-          m_colors[(size_t)wPos++]=MWAWColor((val>>7)& 0xF8, (val>>2) & 0xF8, (unsigned char)(val << 3));
+          m_colors[size_t(wPos++)]=MWAWColor((val>>7)& 0xF8, (val>>2) & 0xF8, static_cast<unsigned char>(val << 3));
         }
       }
       else if (nPlanes==1) {
         for (int x = 0, rPos = 0; x < W; x++) {
           if (nBytes==4) rPos++;
-          m_colors[(size_t)wPos++]=MWAWColor(values[(size_t)rPos], values[size_t(rPos+1)],  values[size_t(rPos+2)]);
+          m_colors[size_t(wPos++)]=MWAWColor(values[size_t(rPos)], values[size_t(rPos+1)],  values[size_t(rPos+2)]);
           rPos+=3;
         }
       }
       else {
         MWAW_DEBUG_MSG(("MacDraft5StyleManagerInternal::Pixmap::readPixmapData: oops find nPlanes != 1\n"));
         for (int x = 0, rPos = (nPlanes==4) ? W:0; x < W; x++) {
-          m_colors[(size_t)wPos++]=MWAWColor(values[(size_t)rPos], values[size_t(rPos+W)],  values[size_t(rPos+2*W)]);
+          m_colors[size_t(wPos++)]=MWAWColor(values[size_t(rPos)], values[size_t(rPos+W)],  values[size_t(rPos+2*W)]);
           rPos+=1;
         }
       }
@@ -189,7 +201,7 @@ struct Pixmap {
 
       int decGray = (numUnset==1) ? 0 : 255/(numUnset-1);
       for (int i = 0; i < numUnset; i++)
-        m_colorTable.push_back(MWAWColor((unsigned char)(255-i*decGray), (unsigned char)(255-i*decGray), (unsigned char)(255-i*decGray)));
+        m_colorTable.push_back(MWAWColor(static_cast<unsigned char>(255-i*decGray), static_cast<unsigned char>(255-i*decGray), static_cast<unsigned char>(255-i*decGray)));
       MWAW_DEBUG_MSG(("MacDraft5StyleManagerInternal::Pixmap::readPixmapData: find index=%d >= numColors=%d\n", maxColorsIndex, numColors));
 
       return true;
@@ -215,7 +227,7 @@ struct Pixmap {
       for (int i = 0; i < nRows; i++) {
         for (int x = 0; x < W; x++) {
           int id=m_indices[rPos++];
-          if (id<0 || id>=(int) numColor) {
+          if (id<0 || id>=static_cast<int>(numColor)) {
             static bool first=true;
             if (first) {
               MWAW_DEBUG_MSG(("MacDraft5StyleManagerInternal::Pixmap::get: find some bad index\n"));
@@ -234,16 +246,16 @@ struct Pixmap {
       for (size_t i=0; i<numColor; ++i) {
         if (!colorByIndices[i]) continue;
         numCols+=colorByIndices[i];
-        totalCol[0]+=(float)colorByIndices[i]*(float)m_colorTable[i].getRed();
-        totalCol[1]+=(float)colorByIndices[i]*(float)m_colorTable[i].getGreen();
-        totalCol[2]+=(float)colorByIndices[i]*(float)m_colorTable[i].getBlue();
+        totalCol[0]+=float(colorByIndices[i])*float(m_colorTable[i].getRed());
+        totalCol[1]+=float(colorByIndices[i])*float(m_colorTable[i].getGreen());
+        totalCol[2]+=float(colorByIndices[i])*float(m_colorTable[i].getBlue());
       }
       if (numCols==0)
         avColor=MWAWColor::black();
       else
-        avColor=MWAWColor((unsigned char)(totalCol[0]/float(numCols)),
-                          (unsigned char)(totalCol[1]/float(numCols)),
-                          (unsigned char)(totalCol[2]/float(numCols)));
+        avColor=MWAWColor(static_cast<unsigned char>(totalCol[0]/float(numCols)),
+                          static_cast<unsigned char>(totalCol[1]/float(numCols)),
+                          static_cast<unsigned char>(totalCol[2]/float(numCols)));
       return pixmap.getBinary(picture);
     }
 
@@ -259,18 +271,18 @@ struct Pixmap {
         for (int x = 0; x < W; x++) {
           MWAWColor col=m_colors[rPos++];
           pixmap.set(x, i, col);
-          totalCol[0]+=(float) col.getRed();
-          totalCol[1]+=(float) col.getGreen();
-          totalCol[2]+=(float) col.getBlue();
+          totalCol[0]+=float(col.getRed());
+          totalCol[1]+=float(col.getGreen());
+          totalCol[2]+=float(col.getBlue());
           ++numCols;
         }
       }
       if (numCols==0)
         avColor=MWAWColor::black();
       else
-        avColor=MWAWColor((unsigned char)(totalCol[0]/float(numCols)),
-                          (unsigned char)(totalCol[1]/float(numCols)),
-                          (unsigned char)(totalCol[2]/float(numCols)));
+        avColor=MWAWColor(static_cast<unsigned char>(totalCol[0]/float(numCols)),
+                          static_cast<unsigned char>(totalCol[1]/float(numCols)),
+                          static_cast<unsigned char>(totalCol[2]/float(numCols)));
 
       return pixmap.getBinary(picture);
     }
@@ -306,8 +318,17 @@ struct Pixmap {
 //! Internal: the state of a MacDraft5StyleManager
 struct State {
   //! constructor
-  State() : m_dataEnd(-1), m_rsrcBegin(-1), m_arrowList(), m_colorList(), m_patternList(), m_dashList(),
-    m_beginToBitmapEntryMap(), m_bitmapIdToPixmapMap(), m_pixIdToPixmapMap(), m_pixIdToPatternIdMap()
+  State()
+    : m_dataEnd(-1)
+    , m_rsrcBegin(-1)
+    , m_arrowList()
+    , m_colorList()
+    , m_patternList()
+    , m_dashList()
+    , m_beginToBitmapEntryMap()
+    , m_bitmapIdToPixmapMap()
+    , m_pixIdToPixmapMap()
+    , m_pixIdToPatternIdMap()
   {
   }
   //! returns an arrow if possible
@@ -379,9 +400,9 @@ struct State {
   //! a map file position to entry ( used to stored intermediar zones )
   std::map<long, MWAWEntry> m_beginToBitmapEntryMap;
   //! a map bitmapId to pixmap map
-  std::map<int, shared_ptr<Pixmap> > m_bitmapIdToPixmapMap;
+  std::map<int, std::shared_ptr<Pixmap> > m_bitmapIdToPixmapMap;
   //! a map pixmapId to pixmap map
-  std::map<int, shared_ptr<Pixmap> > m_pixIdToPixmapMap;
+  std::map<int, std::shared_ptr<Pixmap> > m_pixIdToPixmapMap;
   //! a map pixmapId to patternId map
   std::map<int, size_t> m_pixIdToPatternIdMap;
 };
@@ -438,7 +459,7 @@ void State::initColors()
       0x535353,0x6d6d6d,0x868686,0xa0a0a0,0xb9b9b9,0xd2d2d2,0xeaeaea,0xcccccc,
       0x999999,0x878787,0x00ffff
     };
-    m_colorList.push_back(colors[i]);
+    m_colorList.push_back(MWAWColor(colors[i]));
   }
 }
 
@@ -563,8 +584,10 @@ void State::initDashs()
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-MacDraft5StyleManager::MacDraft5StyleManager(MacDraft5Parser &parser) :
-  m_parser(parser), m_parserState(parser.getParserState()), m_state(new MacDraft5StyleManagerInternal::State)
+MacDraft5StyleManager::MacDraft5StyleManager(MacDraft5Parser &parser)
+  : m_parser(parser)
+  , m_parserState(parser.getParserState())
+  , m_state(new MacDraft5StyleManagerInternal::State)
 {
 }
 
@@ -753,33 +776,31 @@ bool MacDraft5StyleManager::getPixmap(int pId, MWAWEmbeddedObject &picture, MWAW
 
 void MacDraft5StyleManager::updatePatterns()
 {
-  for (std::map<int, size_t>::const_iterator it=m_state->m_pixIdToPatternIdMap.begin();
-       it!=m_state->m_pixIdToPatternIdMap.end(); ++it) {
+  for (auto it : m_state->m_pixIdToPatternIdMap) {
     MWAWEmbeddedObject picture;
     MWAWVec2i bitmapSize;
     MWAWColor averageColor;
-    if (!getPixmap(it->first, picture, bitmapSize, averageColor)) continue;
-    if (it->second>=m_state->m_patternList.size()) {
-      MWAW_DEBUG_MSG(("MWAWMacDraft5StyleManager::updatePatterns: oops patterns id seems bad for %d\n", it->first));
+    if (!getPixmap(it.first, picture, bitmapSize, averageColor)) continue;
+    if (it.second>=m_state->m_patternList.size()) {
+      MWAW_DEBUG_MSG(("MWAWMacDraft5StyleManager::updatePatterns: oops patterns id seems bad for %d\n", it.first));
       continue;
     }
-    shared_ptr<MacDraft5StyleManagerInternal::Pixmap> pixmap=m_state->m_pixIdToPixmapMap.find(it->first)->second;
-    m_state->m_patternList[it->second]=MWAWGraphicStyle::Pattern(bitmapSize, picture, averageColor);
+    auto pixmap=m_state->m_pixIdToPixmapMap.find(it.first)->second;
+    m_state->m_patternList[it.second]=MWAWGraphicStyle::Pattern(bitmapSize, picture, averageColor);
   }
   // check for unused pixmap
-  std::map<int, shared_ptr<MacDraft5StyleManagerInternal::Pixmap> >::const_iterator it;
-  for (it=m_state->m_pixIdToPixmapMap.begin(); it!=m_state->m_pixIdToPixmapMap.end(); ++it) {
-    if (m_state->m_pixIdToPatternIdMap.find(it->first)!=m_state->m_pixIdToPatternIdMap.end() || !it->second)
+  for (auto it : m_state->m_pixIdToPixmapMap) {
+    if (m_state->m_pixIdToPatternIdMap.find(it.first)!=m_state->m_pixIdToPatternIdMap.end() || !it.second)
       continue;
     static bool first=true;
     if (first) {
-      MWAW_DEBUG_MSG(("MWAWMacDraft5StyleManager::updatePatterns: find unread pixmap %d\n", it->first));
+      MWAW_DEBUG_MSG(("MWAWMacDraft5StyleManager::updatePatterns: find unread pixmap %d\n", it.first));
       first=false;
     }
     MWAWEmbeddedObject picture;
     MWAWVec2i bitmapSize;
     MWAWColor averageColor;
-    getPixmap(it->first, picture, bitmapSize, averageColor);
+    getPixmap(it.first, picture, bitmapSize, averageColor);
   }
 }
 
@@ -798,7 +819,7 @@ bool MacDraft5StyleManager::readBitmapZones()
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
   if (m_state->m_rsrcBegin>0)
     input->pushLimit(m_state->m_rsrcBegin);
-  std::map<long, MWAWEntry>::iterator it=m_state->m_beginToBitmapEntryMap.begin();
+  auto it=m_state->m_beginToBitmapEntryMap.begin();
   m_state->m_dataEnd=it->first;
   long lastPos=it->first;
   while (it!=m_state->m_beginToBitmapEntryMap.end()) {
@@ -827,10 +848,9 @@ bool MacDraft5StyleManager::readResources()
   // first look the resource manager
   MWAWRSRCParserPtr rsrcParser = m_parserState->m_rsrcParser;
   if (rsrcParser) {
-    std::multimap<std::string, MWAWEntry> &entryMap = rsrcParser->getEntriesMap();
-    std::multimap<std::string, MWAWEntry>::iterator it=entryMap.begin();
-    while (it!=entryMap.end())
-      readResource(it++->second, true);
+    auto &entryMap = rsrcParser->getEntriesMap();
+    for (auto &it : entryMap)
+      readResource(it.second, true);
   }
 
   MWAWInputStreamPtr input = m_parserState->m_input;
@@ -840,25 +860,25 @@ bool MacDraft5StyleManager::readResources()
     return false;
   }
   input->seek(-10, librevenge::RVNG_SEEK_END);
-  int dSz=(int) input->readULong(2);
+  auto dSz=static_cast<int>(input->readULong(2));
   if (dSz<28 || dSz>=endPos)
     return false;
   std::string name("");
-  for (int i=0; i<8; ++i) name+=(char) input->readULong(1);
+  for (int i=0; i<8; ++i) name+=char(input->readULong(1));
   if (name!="RBALRPH ") return false;
   input->seek(-dSz, librevenge::RVNG_SEEK_END);
   long pos=input->tell();
   libmwaw::DebugFile &ascFile=m_parserState->m_asciiFile;
   libmwaw::DebugStream f;
   f << "Entries(RSRCMap):";
-  long depl=(long) input->readULong(4);
+  auto depl=long(input->readULong(4));
   long debRSRCPos=endPos-depl;
   if (depl>endPos || debRSRCPos>pos) {
     MWAW_DEBUG_MSG(("MacDraft5StyleManager::readResources: the depl0 is bad\n"));
     return false;
   }
   f << "debPos=" << std::hex << debRSRCPos << std::dec << ",";
-  depl=(long) input->readULong(4);
+  depl=long(input->readULong(4));
   if (pos-depl!=debRSRCPos) {
     MWAW_DEBUG_MSG(("MacDraft5StyleManager::readResources: the depl1 is bad\n"));
     f << "###";
@@ -869,7 +889,7 @@ bool MacDraft5StyleManager::readResources()
   }
 
   name="";
-  for (int i=0; i<4; ++i) name +=(char) input->readULong(1);
+  for (int i=0; i<4; ++i) name +=char(input->readULong(1));
   if (name!="RSRC") {
     MWAW_DEBUG_MSG(("MacDraft5StyleManager::readResources: can not find the resource name\n"));
     f << "###";
@@ -880,7 +900,7 @@ bool MacDraft5StyleManager::readResources()
   }
   int N=(dSz-22)/2;
   for (int i=0; i<N; ++i) { // f0=1
-    int val=(int)input->readLong(2);
+    auto val=static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
   ascFile.addPos(pos);
@@ -890,7 +910,7 @@ bool MacDraft5StyleManager::readResources()
   input->seek(debRSRCPos, librevenge::RVNG_SEEK_SET);
   while (!input->isEnd()) {
     pos=input->tell();
-    long fSz=(long) input->readULong(4);
+    auto fSz=long(input->readULong(4));
     if (fSz==0) {
       ascFile.addPos(pos);
       ascFile.addNote("_");
@@ -913,11 +933,11 @@ bool MacDraft5StyleManager::readResources()
     }
     MWAWEntry entry;
     entry.setBegin(pos+16);
-    entry.setLength((long) input->readULong(4));
+    entry.setLength(long(input->readULong(4)));
     name="";
-    for (int i=0; i<4; ++i) name+=(char) input->readULong(1);
+    for (int i=0; i<4; ++i) name+=char(input->readULong(1));
     entry.setType(name);
-    entry.setId((int) input->readLong(2));
+    entry.setId(static_cast<int>(input->readLong(2)));
     if (entry.end()>endPos || name.empty()) {
       ascFile.addPos(pos);
       ascFile.addNote("Entries(rsrcBAD):###");
@@ -992,7 +1012,7 @@ bool MacDraft5StyleManager::readResource(MWAWEntry &entry, bool inRsrc)
     }
     else {
       input->seek(entry.begin(), librevenge::RVNG_SEEK_SET);
-      int val=(int) input->readLong(2);
+      auto val=static_cast<int>(input->readLong(2));
       if (val!=100) // always 100?
         f << "f0=" << val << ",";
     }
@@ -1079,15 +1099,15 @@ bool MacDraft5StyleManager::readFonts(MWAWEntry const &entry, bool inRsrc)
       break;
     f.str("");
     f << "Fonts-" << n++ << ":";
-    int fId=(int) input->readULong(2);
+    auto fId=static_cast<int>(input->readULong(2));
     f<<"fId=" << fId << ",";
-    int sSz=(int) input->readULong(1);
+    auto sSz=static_cast<int>(input->readULong(1));
     if (pos+3+sSz>entry.end()) {
       input->seek(pos,librevenge::RVNG_SEEK_SET);
       break;
     }
     std::string name("");
-    for (int c=0; c<sSz; ++c) name += (char) input->readULong(1);
+    for (int c=0; c<sSz; ++c) name += char(input->readULong(1));
     f << name << ",";
     if (!name.empty())
       m_parserState->m_fontConverter->setCorrespondance(fId, name);
@@ -1120,7 +1140,7 @@ bool MacDraft5StyleManager::readColors(MWAWEntry const &entry, bool inRsrc)
     MWAW_DEBUG_MSG(("MacDraft5StyleManager::readColors: entry id seems odd\n"));
     f << "##id=" << entry.id() << ",";
   }
-  int N=(int) input->readLong(2);
+  auto N=static_cast<int>(input->readLong(2));
   f << "N=" << N << ",";
   if (N*16+16!=entry.length()) {
     f << "###";
@@ -1129,10 +1149,10 @@ bool MacDraft5StyleManager::readColors(MWAWEntry const &entry, bool inRsrc)
   }
   int val;
   for (int i=0; i<5; ++i) { // f2=[8c]0[01][0-c]
-    val=(int) input->readULong(2);
+    val=static_cast<int>(input->readULong(2));
     if (val) f << "fl" << i << "=" << std::hex << val << std::dec << ",";
   }
-  val=(int) input->readULong(4);
+  val=static_cast<int>(input->readULong(4));
   if (val) f << "unkn=" << std::hex << val << std::dec << ",";
   ascFile.addPos(entry.begin()-(inRsrc ? 4 : 16));
   ascFile.addNote(f.str().c_str());
@@ -1143,12 +1163,12 @@ bool MacDraft5StyleManager::readColors(MWAWEntry const &entry, bool inRsrc)
     f.str("");
     f << "Color-" << i << ":";
     uint8_t col[3];
-    for (int j=0; j<3; ++j) col[j]=uint8_t(input->readULong(2)>>8);
+    for (auto &c : col) c=static_cast<uint8_t>(input->readULong(2)>>8);
     MWAWColor color(col[0],col[1],col[2]);
     f << color << ",";
     m_state->m_colorList.push_back(color);
     for (int j=0; j<5; ++j) { // f0=0|2, f1=0|5(gray?), f3=id?
-      val=(int) input->readLong(2);
+      val=static_cast<int>(input->readLong(2));
       if (val) f << "f" << j << "=" << val << ",";
     }
     input->seek(pos+16, librevenge::RVNG_SEEK_SET);
@@ -1176,7 +1196,7 @@ bool MacDraft5StyleManager::readDashes(MWAWEntry const &entry, bool inRsrc)
     MWAW_DEBUG_MSG(("MacDraft5StyleManager::readDashes: entry id seems odd\n"));
     f << "##id=" << entry.id() << ",";
   }
-  int N=int(entry.length()/16);
+  auto N=int(entry.length()/16);
   ascFile.addPos(entry.begin()-(inRsrc ? 4 : 16));
   ascFile.addNote(f.str().c_str());
 
@@ -1184,7 +1204,7 @@ bool MacDraft5StyleManager::readDashes(MWAWEntry const &entry, bool inRsrc)
     long pos=input->tell();
     f.str("");
     f << "Dash-" << i << ":";
-    int n=(int) input->readULong(1);
+    auto n=static_cast<int>(input->readULong(1));
     if (n>15) {
       MWAW_DEBUG_MSG(("MacDraft5StyleManager::readDashes: n is bad\n"));
       f << "##n=" << n << ",";
@@ -1193,7 +1213,7 @@ bool MacDraft5StyleManager::readDashes(MWAWEntry const &entry, bool inRsrc)
     std::vector<float> dash;
     f << "[";
     for (int j=0; j<n; ++j) {
-      dash.push_back((float) input->readULong(1));
+      dash.push_back(float(input->readULong(1)));
       f << dash.back() << ",";
     }
     f << "],";
@@ -1225,44 +1245,44 @@ bool MacDraft5StyleManager::readPatterns(MWAWEntry const &entry, bool inRsrc)
   }
   int val;
   for (int i=0; i<4; ++i) { // f0=0|1|-1, f1=0|-1
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
-  val=(int) input->readULong(4);
+  val=static_cast<int>(input->readULong(4));
   if (val) f << "unkn=" << std::hex << val << std::dec << ",";
   ascFile.addPos(entry.begin()-(inRsrc ? 4 : 16));
   ascFile.addNote(f.str().c_str());
 
-  size_t N=size_t(entry.length()/12-1);
+  auto N=size_t(entry.length()/12-1);
   m_state->m_patternList.resize(N);
   for (size_t i=0; i<N; ++i) {
     long pos=input->tell();
     f.str("");
     f << "Pattern-" << i << ":";
-    int type=(int) input->readLong(2);
+    auto type=static_cast<int>(input->readLong(2));
     switch (type) {
     case 0: {
-      val=(int) input->readLong(2); // always 0
+      val=static_cast<int>(input->readLong(2)); // always 0
       if (val) f << "f0=" << val << ",";
       MWAWGraphicStyle::Pattern pat;
       pat.m_dim=MWAWVec2i(8,8);
       pat.m_data.resize(8);
       pat.m_colors[0]=MWAWColor::white();
       pat.m_colors[1]=MWAWColor::black();
-      for (size_t j=0; j<8; ++j) pat.m_data[j]=(uint8_t) input->readULong(1);
+      for (auto &data : pat.m_data) data=static_cast<uint8_t>(input->readULong(1));
       f << pat << ",";
       m_state->m_patternList[i]=pat;
       break;
     }
     case 1: {
-      int pixId=(int) input->readLong(2);
+      auto pixId=static_cast<int>(input->readLong(2));
       f << "id[pixpat]=" << pixId << ",";
-      if (m_state->m_pixIdToPatternIdMap.find(pixId)!=m_state->m_pixIdToPatternIdMap.end()) {
+      if (m_state->m_pixIdToPatternIdMap.find(pixId)==m_state->m_pixIdToPatternIdMap.end())
+        m_state->m_pixIdToPatternIdMap[pixId]=i;
+      else if (m_state->m_pixIdToPatternIdMap.find(pixId)->second!=i) { // can be normal if def in rsrc and data fork
         MWAW_DEBUG_MSG(("MacDraft5StyleManager::readPatterns: find a dupplicated pixId\n"));
         f << "###";
       }
-      else
-        m_state->m_pixIdToPatternIdMap[pixId]=i;
       break;
     }
     default:
@@ -1290,41 +1310,41 @@ bool MacDraft5StyleManager::readBitmap(MWAWEntry const &entry)
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
   libmwaw::DebugStream f;
   f << "Entries(Bitmap)[" << entry.id() << "]:";
-  long fSz=(long) input->readULong(4);
+  auto fSz=long(input->readULong(4));
   if (fSz+4!=entry.length()) {
     MWAW_DEBUG_MSG(("MacDraft5StyleManager::readBitmap: zone size seems bad\n"));
     f << "#sz[entry]=" << fSz << ",";
   }
-  fSz=(long) input->readULong(4);
+  fSz=long(input->readULong(4));
   if (fSz+8>entry.length()) {
     MWAW_DEBUG_MSG(("MacDraft5StyleManager::readBitmap: data size seems bad\n"));
     f << "#sz[data]=" << fSz << ",";
   }
   // now the pixmap
-  shared_ptr<MacDraft5StyleManagerInternal::Pixmap> pixmap(new MacDraft5StyleManagerInternal::Pixmap);
-  pixmap->m_rowBytes = (int) input->readULong(2);
+  std::shared_ptr<MacDraft5StyleManagerInternal::Pixmap> pixmap(new MacDraft5StyleManagerInternal::Pixmap);
+  pixmap->m_rowBytes = static_cast<int>(input->readULong(2));
   pixmap->m_rowBytes &= 0x3FFF;
 
   // read the rectangle: bound
   int dim[4];
-  for (int d = 0; d < 4; d++) dim[d] = (int) input->readLong(2);
+  for (auto &d : dim) d = static_cast<int>(input->readLong(2));
   pixmap->m_rect = MWAWBox2i(MWAWVec2i(dim[1],dim[0]), MWAWVec2i(dim[3],dim[2]));
   if (pixmap->m_rect.size().x() <= 0 || pixmap->m_rect.size().y() <= 0) {
     MWAW_DEBUG_MSG(("MacDraft5StyleManager::readBitmap: find odd bound rectangle ... \n"));
     return false;
   }
-  pixmap->m_version = (int) input->readLong(2);
-  pixmap->m_packType = (int) input->readLong(2);
-  pixmap->m_packSize = (int) input->readLong(4);
-  for (int c = 0; c < 2; c++) {
-    pixmap->m_resolution[c] = (int) input->readLong(2);
+  pixmap->m_version = static_cast<int>(input->readLong(2));
+  pixmap->m_packType = static_cast<int>(input->readLong(2));
+  pixmap->m_packSize = static_cast<int>(input->readLong(4));
+  for (auto &res : pixmap->m_resolution) {
+    res = static_cast<int>(input->readLong(2));
     input->readLong(2);
   }
-  pixmap->m_pixelType = (int) input->readLong(2);
-  pixmap->m_pixelSize = (int) input->readLong(2);
-  pixmap->m_compCount = (int) input->readLong(2);
-  pixmap->m_compSize = (int) input->readLong(2);
-  pixmap->m_planeBytes = (int) input->readLong(4);
+  pixmap->m_pixelType = static_cast<int>(input->readLong(2));
+  pixmap->m_pixelSize = static_cast<int>(input->readLong(2));
+  pixmap->m_compCount = static_cast<int>(input->readLong(2));
+  pixmap->m_compSize = static_cast<int>(input->readLong(2));
+  pixmap->m_planeBytes = static_cast<int>(input->readLong(4));
   f << *pixmap;
   input->seek(8, librevenge::RVNG_SEEK_CUR); // color handle, reserved
   ascFile.addPos(entry.begin());
@@ -1370,7 +1390,7 @@ bool MacDraft5StyleManager::readPixPat(MWAWEntry const &entry, bool inRsrc)
   libmwaw::DebugStream f;
   f << "Entries(PixPat)[" << entry.id() << "]:";
   for (int i=0; i<16; ++i) {
-    int val=(int) input->readLong(2);
+    auto val=static_cast<int>(input->readLong(2));
     static int const expected[]= {1,0,0x1c,0,0x4e,0,0,-1,0,0,
                                   -21931,-21931,-21931,-21931,0,0
                                  }; // pattern, 0, 0
@@ -1378,32 +1398,32 @@ bool MacDraft5StyleManager::readPixPat(MWAWEntry const &entry, bool inRsrc)
       f << "f" << i << "=" << val << ",";
   }
   // now the pixmap
-  shared_ptr<MacDraft5StyleManagerInternal::Pixmap> pixmap(new MacDraft5StyleManagerInternal::Pixmap);
-  pixmap->m_rowBytes = (int) input->readULong(2);
+  std::shared_ptr<MacDraft5StyleManagerInternal::Pixmap> pixmap(new MacDraft5StyleManagerInternal::Pixmap);
+  pixmap->m_rowBytes = static_cast<int>(input->readULong(2));
   pixmap->m_rowBytes &= 0x3FFF;
 
   // read the rectangle: bound
   int dim[4];
-  for (int d = 0; d < 4; d++) dim[d] = (int) input->readLong(2);
+  for (auto &d : dim) d = static_cast<int>(input->readLong(2));
   pixmap->m_rect = MWAWBox2i(MWAWVec2i(dim[1],dim[0]), MWAWVec2i(dim[3],dim[2]));
   if (pixmap->m_rect.size().x() <= 0 || pixmap->m_rect.size().y() <= 0) {
     MWAW_DEBUG_MSG(("MacDraft5StyleManager::readPixPat: find odd bound rectangle ... \n"));
     return false;
   }
-  pixmap->m_version = (int) input->readLong(2);
-  pixmap->m_packType = (int) input->readLong(2);
-  pixmap->m_packSize = (int) input->readLong(4);
-  for (int c = 0; c < 2; c++) {
-    pixmap->m_resolution[c] = (int) input->readLong(2);
+  pixmap->m_version = static_cast<int>(input->readLong(2));
+  pixmap->m_packType = static_cast<int>(input->readLong(2));
+  pixmap->m_packSize = static_cast<int>(input->readLong(4));
+  for (auto &res : pixmap->m_resolution) {
+    res = static_cast<int>(input->readLong(2));
     input->readLong(2);
   }
-  pixmap->m_pixelType = (int) input->readLong(2);
-  pixmap->m_pixelSize = (int) input->readLong(2);
-  pixmap->m_compCount = (int) input->readLong(2);
-  pixmap->m_compSize = (int) input->readLong(2);
-  pixmap->m_planeBytes = (int) input->readLong(4);
+  pixmap->m_pixelType = static_cast<int>(input->readLong(2));
+  pixmap->m_pixelSize = static_cast<int>(input->readLong(2));
+  pixmap->m_compCount = static_cast<int>(input->readLong(2));
+  pixmap->m_compSize = static_cast<int>(input->readLong(2));
+  pixmap->m_planeBytes = static_cast<int>(input->readLong(4));
   f << *pixmap;
-  long colorDepl=(long) input->readULong(4);
+  auto colorDepl=long(input->readULong(4));
   input->seek(4, librevenge::RVNG_SEEK_CUR); // reserved
   ascFile.addPos(entry.begin()-(inRsrc ? 4 : 16));
   ascFile.addNote(f.str().c_str());
@@ -1429,7 +1449,7 @@ bool MacDraft5StyleManager::readPixPat(MWAWEntry const &entry, bool inRsrc)
     long colorPos=input->tell();
     f.str("");
     f << "PixPat-colors:";
-    int N=(int) input->readULong(2);
+    auto N=static_cast<int>(input->readULong(2));
     if (N>2000) {
       MWAW_DEBUG_MSG(("MacDraft5StyleManager::readPixPat: the number of color seems bad\n"));
       f << "###";
@@ -1441,9 +1461,9 @@ bool MacDraft5StyleManager::readPixPat(MWAWEntry const &entry, bool inRsrc)
     int numColor=int(entry.end()-colorPos)/8;
     bool ok=true;
     for (int i=0; i<numColor; ++i) {
-      int id=(int) input->readULong(2);
+      auto id=static_cast<int>(input->readULong(2));
       uint8_t col[3];
-      for (int j=0; j<3; ++j) col[j]=(uint8_t)(input->readULong(2)>>8);
+      for (auto &c : col) c=static_cast<uint8_t>(input->readULong(2)>>8);
       MWAWColor color(col[0],col[1],col[2]);
       if (id!=i) f << "col" << id << "=" << color;
       else f << color;
@@ -1498,15 +1518,15 @@ bool MacDraft5StyleManager::readVersion(MWAWEntry &entry)
   libmwaw::DebugFile &ascFile=m_parserState->m_asciiFile;
   libmwaw::DebugStream f;
   input->seek(entry.begin(), librevenge::RVNG_SEEK_SET);
-  vers.m_majorVersion = (int) input->readULong(1);
-  vers.m_minorVersion = (int) input->readULong(1);
-  long val = (long) input->readULong(1);
+  vers.m_majorVersion = static_cast<int>(input->readULong(1));
+  vers.m_minorVersion = static_cast<int>(input->readULong(1));
+  auto val = long(input->readULong(1));
   if (val) f << "devStage=" << val << ",";
-  val = (long) input->readULong(1);
+  val = long(input->readULong(1));
   if (val) f << "preReleaseLevel=" << std::hex << val << std::dec << ",";
-  vers.m_countryCode = (int) input->readULong(2);
+  vers.m_countryCode = static_cast<int>(input->readULong(2));
   for (int i = 0; i < 2; i++) {
-    int sz = (int) input->readULong(1);
+    auto sz = static_cast<int>(input->readULong(1));
     long pos = input->tell();
     if (pos+sz > entry.end()) {
       MWAW_DEBUG_MSG(("MWAWMacDraft5StyleManager::readVersion: can not read strings %d\n",i));
@@ -1514,7 +1534,7 @@ bool MacDraft5StyleManager::readVersion(MWAWEntry &entry)
     }
     std::string str("");
     for (int c = 0; c < sz; c++)
-      str+=(char) input->readULong(1);
+      str+=char(input->readULong(1));
     if (i==0)
       vers.m_versionString = str;
     else
@@ -1534,7 +1554,8 @@ bool MacDraft5StyleManager::readBitmapList(MWAWEntry const &entry, bool inRsrc)
 {
   if (inRsrc && !m_parserState->m_rsrcParser) return false;
   MWAWInputStreamPtr input = inRsrc ? m_parserState->m_rsrcParser->getInput() : m_parserState->m_input;
-  if (!input || !entry.valid() || entry.length()<30 || (entry.length()%12)<6 || (entry.length()%12)>7) {
+  MWAWInputStreamPtr fileInput=m_parserState->m_input;
+  if (!input || !fileInput || !entry.valid() || entry.length()<30 || (entry.length()%12)<6 || (entry.length()%12)>7) {
     MWAW_DEBUG_MSG(("MacDraft5StyleManager::readBitmapList: entry is invalid\n"));
     return false;
   }
@@ -1549,19 +1570,19 @@ bool MacDraft5StyleManager::readBitmapList(MWAWEntry const &entry, bool inRsrc)
   }
   int val;
   for (int i=0; i<3; ++i) { // always 0
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
-  int N=(int) input->readULong(2);
+  auto N=static_cast<int>(input->readULong(2));
   if (30+12*N!=entry.length() && 31+12*N!=entry.length()) {
     MWAW_DEBUG_MSG(("MacDraft5StyleManager::readBitmapList:N seems bad\n"));
     f << "##N=" << N << ",";
     if (30+12*N>entry.length())
       N=int((entry.length()-30)/12);
   }
-  val=(int) input->readLong(2); // always 0 ?
+  val=static_cast<int>(input->readLong(2)); // always 0 ?
   if (val) f << "f3=" << val << ",";
-  val=(int) input->readLong(2); // always c
+  val=static_cast<int>(input->readLong(2)); // always c
   if (val!=12) f << "#fSz=" << val << ",";
   long dataSz=input->readLong(4);
   if ((dataSz%12) || dataSz>12*N) {
@@ -1569,42 +1590,40 @@ bool MacDraft5StyleManager::readBitmapList(MWAWEntry const &entry, bool inRsrc)
     f << "##dataSz=" << dataSz << ",";
   }
   for (int i=0; i<7; ++i) {
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     static int const expected[]= {0,0xc,0,4,0,0,0};
     if (val!=expected[i]) f << "f" << i+4 << "=" << val << ",";
   }
 
   ascFile.addPos(entry.begin()-(inRsrc ? 4 : 16));
   ascFile.addNote(f.str().c_str());
-
   for (long i=0; i<N; ++i) {
     long pos=input->tell();
     f.str("");
     f << "BitmList-" << i << ":";
     MWAWEntry dataEntry;
-    dataEntry.setBegin((long) input->readULong(4));
-    dataEntry.setLength((long) input->readULong(4));
+    dataEntry.setBegin(long(input->readULong(4)));
+    dataEntry.setLength(long(input->readULong(4)));
 
     if (dataEntry.begin()==0) // none
       ;
-    else if (!dataEntry.valid() || !input->checkPosition(dataEntry.end())) {
+    else if (!dataEntry.valid() || !fileInput->checkPosition(dataEntry.end())) {
       MWAW_DEBUG_MSG(("MacDraft5StyleManager::readBitmapList:dataEntry seems bad\n"));
       f << "###data=" << std::hex << dataEntry.begin() << ":" << dataEntry.length() << ",";
     }
     else {
       f << "data=" << std::hex << dataEntry.begin() << ":" << dataEntry.length() << ",";
-      dataEntry.setId((int) i);
+      dataEntry.setId(static_cast<int>(i));
       dataEntry.setType("bitmap");
       if (m_state->m_beginToBitmapEntryMap.find(dataEntry.begin())==m_state->m_beginToBitmapEntryMap.end())
         m_state->m_beginToBitmapEntryMap[dataEntry.begin()]=dataEntry;
-      else {
+      else if (m_state->m_beginToBitmapEntryMap.find(dataEntry.begin())->second!=dataEntry) {
         MWAW_DEBUG_MSG(("MacDraft5StyleManager::readBitmapList:dataEntry already exist\n"));
         f << "###dupplicated,";
-
       }
     }
     for (int j=0; j<4; ++j) { // fl0=fl1=1
-      val=(int) input->readLong(1);
+      val=static_cast<int>(input->readLong(1));
       if (val==1) f << "fl" << j << ",";
       else if (val) f << "#fl" << j << "=" << val << ",";
     }
@@ -1633,24 +1652,24 @@ bool MacDraft5StyleManager::readRSRCList(MWAWEntry const &entry, bool inRsrc)
   libmwaw::DebugFile &ascFile = inRsrc ? m_parserState->m_rsrcParser->ascii() : m_parserState->m_asciiFile;
   libmwaw::DebugStream f;
   f << "Entries(RSRCList)[" << entry.type() << "-" << entry.id() << "]:";
-  int val=(int) input->readLong(2);
+  auto val=static_cast<int>(input->readLong(2));
   if (val!=entry.id()) f << "#id=" << val << ",";
   std::string name("");
-  for (int i=0; i<4; ++i) name+=(char) input->readULong(1);
+  for (int i=0; i<4; ++i) name+=char(input->readULong(1));
   if (name!=entry.type()) f << "#type=" << name << ",";
-  val=(int) input->readULong(2); // 40|48|..|28d6
+  val=static_cast<int>(input->readULong(2)); // 40|48|..|28d6
   if (val)
     f << "fl=" << std::hex << val << ",";
   for (int i=0; i<8; ++i) { // f3=f5=c|78, f6=0|4, f7=1|6|8
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     static int const expected[]= {0,0xc,0,0xc,0,0xc,0,0};
     if (val!=expected[i]) f << "f" << i << "=" << val << ",";
   }
-  int id=(int) input->readULong(2);
+  auto id=static_cast<int>(input->readULong(2));
   name="";
-  for (int i=0; i<4; ++i) name+=(char) input->readULong(1);
+  for (int i=0; i<4; ++i) name+=char(input->readULong(1));
   f << name << ":" << id << ",";
-  val=(int) input->readLong(1); // 0|-1|3f
+  val=static_cast<int>(input->readLong(1)); // 0|-1|3f
   if (val)
     f << "fl2=" << std::hex << val << ",";
   ascFile.addPos(entry.begin()-(inRsrc ? 4 : 16));
@@ -1674,7 +1693,7 @@ bool MacDraft5StyleManager::readOpcd(MWAWEntry const &entry, bool inRsrc)
   long N=entry.length()/4;
   input->seek(entry.begin(), librevenge::RVNG_SEEK_SET);
   for (long i=0; i<N; ++i) { // find a serie of 125k 0x3f800000: double4?
-    long val=(long) input->readULong(4);
+    auto val=long(input->readULong(4));
     if (val!=0x3f800000)
       f << "f" << i << "=" << std::hex << val << std::dec << ",";
   }
@@ -1686,11 +1705,4 @@ bool MacDraft5StyleManager::readOpcd(MWAWEntry const &entry, bool inRsrc)
   return true;
 }
 
-
-////////////////////////////////////////////////////////////
-//
-// send data
-//
-////////////////////////////////////////////////////////////
-
 // vim: set filetype=cpp tabstop=2 shiftwidth=2 cindent autoindent smartindent noexpandtab:
