@@ -62,14 +62,26 @@ namespace MacWrtProStructuresInternal
 struct Block {
   enum Type { UNKNOWN, GRAPHIC, TEXT, NOTE };
   //! the constructor
-  Block() :m_type(-1), m_contentType(UNKNOWN), m_fileBlock(0), m_id(-1), m_attachment(false), m_page(-1), m_box(),
-    m_baseline(0.), m_surfaceColor(MWAWColor::white()), m_lineBorder(), m_textPos(0), m_isHeader(false),
-    m_row(0), m_col(0), m_textboxCellType(0), m_extra(""), m_send(false)
+  Block()
+    : m_type(-1)
+    , m_contentType(UNKNOWN)
+    , m_fileBlock(0)
+    , m_id(-1)
+    , m_attachment(false)
+    , m_page(-1)
+    , m_box()
+    , m_baseline(0.)
+    , m_surfaceColor(MWAWColor::white())
+    , m_lineBorder()
+    , m_textPos(0)
+    , m_isHeader(false)
+    , m_row(0)
+    , m_col(0)
+    , m_textboxCellType(0)
+    , m_extra("")
+    , m_send(false)
   {
-    for (int i=0; i < 4; ++i) {
-      m_borderWList[i]=0;
-      m_borderCellList[i]=MWAWBorder();
-    }
+    for (auto &w : m_borderWList) w= 0;
   }
 
   //! operator<<
@@ -193,8 +205,8 @@ struct Block {
   {
     if (m_lineBorder.m_color.isWhite() || m_lineBorder.isEmpty())
       return false;
-    for (int i=0; i < 4; ++i) {
-      if (m_borderWList[i] > 0)
+    for (auto w : m_borderWList) {
+      if (w > 0)
         return true;
     }
     return false;
@@ -204,7 +216,7 @@ struct Block {
   {
     MWAWPosition res;
     if (m_attachment) {
-      res = MWAWPosition(MWAWVec2i(0,0), m_box.size(), librevenge::RVNG_POINT);
+      res = MWAWPosition(MWAWVec2f(0,0), m_box.size(), librevenge::RVNG_POINT);
       res.setRelativePosition(MWAWPosition::Char, MWAWPosition::XLeft, getRelativeYPos());
     }
     else {
@@ -302,9 +314,12 @@ struct Block {
 //! Internal: the fonts
 struct Font {
   //! the constructor
-  Font(): m_font(), m_flags(0), m_token(-1)
+  Font()
+    : m_font()
+    , m_flags(0)
+    , m_token(-1)
   {
-    for (int i = 0; i < 5; ++i) m_values[i] = 0;
+    for (auto &val : m_values) val = 0;
   }
   //! operator<<
   friend std::ostream &operator<<(std::ostream &o, Font const &font)
@@ -336,13 +351,14 @@ struct Font {
 
 ////////////////////////////////////////
 /** Internal: class to store the paragraph properties */
-struct Paragraph : public MWAWParagraph {
+struct Paragraph final : public MWAWParagraph {
   //! Constructor
-  Paragraph() :  m_value(0)
+  Paragraph()
+    :  m_value(0)
   {
   }
   //! destructor
-  ~Paragraph();
+  ~Paragraph() final;
   //! operator<<
   friend std::ostream &operator<<(std::ostream &o, Paragraph const &ind)
   {
@@ -360,9 +376,12 @@ Paragraph::~Paragraph()
 
 ////////////////////////////////////////
 //! Internal: the cell of a MacWrtProStructure
-struct Cell : public MWAWCell {
+struct Cell final : public MWAWCell {
   //! constructor
-  Cell(MacWrtProStructures &parser, Block *block) : MWAWCell(), m_parser(parser), m_blockId(0)
+  Cell(MacWrtProStructures &parser, Block *block)
+    : MWAWCell()
+    , m_parser(parser)
+    , m_blockId(0)
   {
     if (!block) return;
     setBdBox(MWAWBox2f(block->m_box.min(), block->m_box.max()-MWAWVec2f(1,1)));
@@ -376,9 +395,9 @@ struct Cell : public MWAWCell {
     }
   }
   //! destructor
-  virtual ~Cell();
+  ~Cell() final;
   //! send the content
-  bool sendContent(MWAWListenerPtr listener, MWAWTable &)
+  bool sendContent(MWAWListenerPtr listener, MWAWTable &) final
   {
     if (m_blockId > 0)
       m_parser.send(m_blockId);
@@ -399,19 +418,19 @@ Cell::~Cell()
 
 ////////////////////////////////////////
 ////////////////////////////////////////
-struct Table : public MWAWTable {
+struct Table final : public MWAWTable {
   //! constructor
   Table() : MWAWTable()
   {
   }
   //! destructor
-  virtual ~Table();
+  ~Table() final;
   //! return a cell corresponding to id
   Cell *get(int id)
   {
     if (id < 0 || id >= numCells()) {
       MWAW_DEBUG_MSG(("MacWrtProStructuresInternal::Table::get: cell %d does not exists\n",id));
-      return 0;
+      return nullptr;
     }
     return static_cast<Cell *>(MWAWTable::get(id).get());
   }
@@ -427,9 +446,14 @@ struct Section {
   enum StartType { S_Line, S_Page, S_PageLeft, S_PageRight };
 
   //! constructor
-  Section() : m_start(S_Page), m_colsPos(), m_textLength(0), m_extra("")
+  Section()
+    : m_start(S_Page)
+    , m_colsPos()
+    , m_textLength(0)
+    , m_extra("")
   {
-    for (int i = 0; i < 2; ++i) m_headerIds[i] = m_footerIds[i] = 0;
+    for (auto &id : m_headerIds) id=0;
+    for (auto &id : m_footerIds) id=0;
   }
   //! returns a MWAWSection
   MWAWSection getSection() const
@@ -452,7 +476,7 @@ struct Section {
   //! return the number of columns
   int numColumns() const
   {
-    int numCols=int(m_colsPos.size()/2);
+    auto numCols=int(m_colsPos.size()/2);
     return numCols ? numCols : 1;
   }
   //! operator<<
@@ -475,7 +499,7 @@ struct Section {
       break;
 #endif
     }
-    size_t numColumns = size_t(sec.numColumns());
+    auto numColumns = size_t(sec.numColumns());
     if (numColumns != 1) {
       o << "nCols=" << numColumns << ",";
       o << "colsPos=[";
@@ -509,9 +533,20 @@ struct Section {
 //! Internal: the state of a MacWrtProStructures
 struct State {
   //! constructor
-  State() : m_version(-1), m_numPages(1), m_inputData(), m_fontsList(), m_paragraphsList(),
-    m_sectionsList(), m_blocksList(), m_blocksMap(), m_tablesMap(),m_footnotesList(),
-    m_headersMap(), m_footersMap(), m_blocksSendSet()
+  State()
+    : m_version(-1)
+    , m_numPages(1)
+    , m_inputData()
+    , m_fontsList()
+    , m_paragraphsList()
+    , m_sectionsList()
+    , m_blocksList()
+    , m_blocksMap()
+    , m_tablesMap()
+    , m_footnotesList()
+    , m_headersMap()
+    , m_footersMap()
+    , m_blocksSendSet()
   {
   }
 
@@ -558,11 +593,11 @@ struct State {
   //! the list of section
   std::vector<Section> m_sectionsList;
   //! the list of block
-  std::vector<shared_ptr<Block> > m_blocksList;
+  std::vector<std::shared_ptr<Block> > m_blocksList;
   //! a map block id -> block
-  std::map<int, shared_ptr<Block> > m_blocksMap;
+  std::map<int, std::shared_ptr<Block> > m_blocksMap;
   //! a map block id -> table
-  std::map<int, shared_ptr<Table> > m_tablesMap;
+  std::map<int, std::shared_ptr<Table> > m_tablesMap;
   //! the foonote list (for MWII)
   std::vector<int> m_footnotesList;
   //! a map page -> header id
@@ -579,9 +614,13 @@ struct State {
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-MacWrtProStructures::MacWrtProStructures(MacWrtProParser &parser) :
-  m_parserState(parser.getParserState()), m_input(), m_mainParser(parser),
-  m_state(), m_asciiFile(MWAWInputStreamPtr()), m_asciiName("")
+MacWrtProStructures::MacWrtProStructures(MacWrtProParser &parser)
+  : m_parserState(parser.getParserState())
+  , m_input()
+  , m_mainParser(parser)
+  , m_state()
+  , m_asciiFile(MWAWInputStreamPtr())
+  , m_asciiName("")
 {
   init();
 }
@@ -620,7 +659,7 @@ int MacWrtProStructures::getHeaderId(int page, int &numSimilar) const
 {
   numSimilar = 1;
   if (version()==0) page = 0;
-  std::map<int, int>::const_iterator it=m_state->m_headersMap.lower_bound(page);
+  auto it=m_state->m_headersMap.lower_bound(page);
   if (it==m_state->m_headersMap.end()) {
     if (m_state->m_numPages>page)
       numSimilar=m_state->m_numPages-page+1;
@@ -640,7 +679,7 @@ int MacWrtProStructures::getFooterId(int page, int &numSimilar) const
 {
   numSimilar = 1;
   if (version()==0) page = 0;
-  std::map<int, int>::const_iterator it=m_state->m_footersMap.lower_bound(page);
+  auto it=m_state->m_footersMap.lower_bound(page);
   if (it==m_state->m_footersMap.end()) {
     if (m_state->m_numPages>page)
       numSimilar=m_state->m_numPages-page+1;
@@ -933,7 +972,7 @@ bool MacWrtProStructures::createZonesV2()
   if (ok) {
     pos = m_input->tell();
     int id = 0;
-    shared_ptr<MacWrtProStructuresInternal::Block> block;
+    std::shared_ptr<MacWrtProStructuresInternal::Block> block;
     while (1) {
       block = readBlockV2(id++);
       if (!block)
@@ -957,7 +996,7 @@ bool MacWrtProStructures::createZonesV2()
 
   int nPages = 1;
   for (int i = 0; i < int(m_state->m_blocksList.size()); ++i) {
-    shared_ptr<MacWrtProStructuresInternal::Block> &block = m_state->m_blocksList[size_t(i)];
+    auto block = m_state->m_blocksList[size_t(i)];
     switch (block->m_type) {
     case 6:
       if (block->m_isHeader)
@@ -990,22 +1029,21 @@ bool MacWrtProStructures::sendMainZone()
 {
   int vers = version();
   for (size_t i = 0; i < m_state->m_blocksList.size(); ++i) {
-    if (!m_state->m_blocksList[i]->isText() ||
-        m_state->m_blocksList[i]->m_send) continue;
-    if (vers == 1 && m_state->m_blocksList[i]->m_type != 5)
+    auto block = m_state->m_blocksList[i];
+    if (!block->isText() || block->m_send) continue;
+    if (vers == 1 && block->m_type != 5)
       continue;
     // fixme
-    if (vers == 0 && m_state->m_blocksList[i]->m_type != -1)
+    if (vers == 0 && block->m_type != -1)
       continue;
-    return send(vers==0 ? int(i) : m_state->m_blocksList[i]->m_id, true);
+    return send(vers==0 ? int(i) : block->m_id, true);
   }
 
   //ok the main zone can be empty
-  for (size_t i = 0; i < m_state->m_blocksList.size(); ++i) {
-    if (m_state->m_blocksList[i]->m_type != 5 ||
-        m_state->m_blocksList[i]->m_send) continue;
+  for (auto block : m_state->m_blocksList) {
+    if (block->m_type != 5 || block->m_send) continue;
 
-    shared_ptr<MacWrtProStructures> THIS
+    std::shared_ptr<MacWrtProStructures> THIS
     (this, MWAW_shared_ptr_noop_deleter<MacWrtProStructures>());
     MacWrtProStructuresListenerState listenerState(THIS, true);
     return true;
@@ -1022,17 +1060,15 @@ void MacWrtProStructures::buildPageStructures()
   // first find the pages break
   std::set<long> set;
   int actPage = 0;
-  for (size_t i = 0; i < m_state->m_blocksList.size(); ++i) {
-    m_state->m_blocksList[i]->m_page = actPage ? actPage : 1; // mainly ok
-    if (m_state->m_blocksList[i]->m_type != 5)
+  for (auto block : m_state->m_blocksList) {
+    block->m_page = actPage ? actPage : 1; // mainly ok
+    if (block->m_type != 5)
       continue;
     actPage++;
-    set.insert(m_state->m_blocksList[i]->m_textPos);
+    set.insert(block->m_textPos);
   }
-  size_t numSections = m_state->m_sectionsList.size();
   long actSectPos = 0;
-  for (size_t i = 0; i < numSections; ++i) {
-    MacWrtProStructuresInternal::Section &sec = m_state->m_sectionsList[i];
+  for (auto &sec : m_state->m_sectionsList) {
     if (sec.m_start != sec.S_Line) set.insert(actSectPos);
     actSectPos += sec.m_textLength;
   }
@@ -1044,8 +1080,7 @@ void MacWrtProStructures::buildPageStructures()
   int actPagePos = 0;
   actPage = 0;
   actSectPos = 0;
-  for (size_t i = 0; i < numSections; ++i) {
-    MacWrtProStructuresInternal::Section &sec = m_state->m_sectionsList[i];
+  for (auto &sec : m_state->m_sectionsList) {
     std::vector<int> listPages;
     actSectPos += sec.m_textLength;
     while (actPagePos < actSectPos) {
@@ -1062,8 +1097,8 @@ void MacWrtProStructures::buildPageStructures()
         footerId = sec.m_footerIds[k];
     }
     if (!headerId && !footerId) continue;
-    for (size_t j = 0; j < listPages.size(); ++j) {
-      int p = listPages[j]+1;
+    for (auto p : listPages) {
+      ++p;
       if (headerId && m_state->m_headersMap.find(p) == m_state->m_headersMap.end())
         m_state->m_headersMap[p] = headerId;
       if (footerId)
@@ -1071,15 +1106,14 @@ void MacWrtProStructures::buildPageStructures()
     }
   }
   // finally mark the attachment
-  std::vector<int> const &listCalled = m_mainParser.getBlocksCalledByToken();
-  for (size_t i = 0; i < listCalled.size(); ++i) {
-    if (m_state->m_blocksMap.find(listCalled[i]) == m_state->m_blocksMap.end()) {
+  auto const &listCalled = m_mainParser.getBlocksCalledByToken();
+  for (auto id : listCalled) {
+    if (m_state->m_blocksMap.find(id) == m_state->m_blocksMap.end()) {
       MWAW_DEBUG_MSG(("MacWrtProStructures::buildPageStructures: can not find attachment block %d...\n",
-                      listCalled[i]));
+                      id));
       continue;
     }
-    shared_ptr<MacWrtProStructuresInternal::Block> block =
-      m_state->m_blocksMap.find(listCalled[i])->second;
+    auto block = m_state->m_blocksMap.find(id)->second;
     block->m_attachment = true;
   }
 }
@@ -1092,19 +1126,18 @@ void MacWrtProStructures::buildTableStructures()
   for (size_t i = 0; i < numBlocks; ++i) {
     if (m_state->m_blocksList[i]->m_type != 3)
       continue;
-    shared_ptr<MacWrtProStructuresInternal::Block> table
-      = m_state->m_blocksList[i];
-    std::vector<shared_ptr<MacWrtProStructuresInternal::Block> > blockList;
+    auto table = m_state->m_blocksList[i];
+    std::vector<std::shared_ptr<MacWrtProStructuresInternal::Block> > blockList;
     size_t j = i+1;
     for (; j < numBlocks; ++j) {
-      shared_ptr<MacWrtProStructuresInternal::Block> cell = m_state->m_blocksList[j];
+      auto cell = m_state->m_blocksList[j];
       if (cell->m_type != 4)
         break;
       if (!table->contains(cell->m_box))
         break;
       bool ok = true;
-      for (size_t k = 0; k < blockList.size(); ++k) {
-        if (cell->intersects(blockList[k]->m_box)) {
+      for (auto block : blockList) {
+        if (cell->intersects(block->m_box)) {
           ok = false;
           break;
         }
@@ -1124,13 +1157,13 @@ void MacWrtProStructures::buildTableStructures()
       continue;
     }
 
-    shared_ptr<MacWrtProStructuresInternal::Table> newTable(new MacWrtProStructuresInternal::Table);
-    for (size_t k = 0; k < numCells; ++k) {
-      blockList[k]->m_send = true;
-      blockList[k]->m_attachment = true;
-      blockList[k]->m_textboxCellType=1;
-      newTable->add(shared_ptr<MacWrtProStructuresInternal::Cell>
-                    (new MacWrtProStructuresInternal::Cell(*this, blockList[k].get())));
+    std::shared_ptr<MacWrtProStructuresInternal::Table> newTable(new MacWrtProStructuresInternal::Table);
+    for (auto block : blockList) {
+      block->m_send = true;
+      block->m_attachment = true;
+      block->m_textboxCellType=1;
+      newTable->add(std::shared_ptr<MacWrtProStructuresInternal::Cell>
+                    (new MacWrtProStructuresInternal::Cell(*this, block.get())));
     }
     m_state->m_tablesMap[table->m_id]=newTable;
   }
@@ -1149,7 +1182,7 @@ bool MacWrtProStructures::readFontsName()
   long pos = m_input->tell();
   libmwaw::DebugStream f;
 
-  long sz = long(m_input->readULong(4));
+  auto sz = long(m_input->readULong(4));
   if (sz == 0) {
     ascii().addPos(pos);
     ascii().addNote("_");
@@ -1165,7 +1198,7 @@ bool MacWrtProStructures::readFontsName()
   }
   m_input->seek(pos+4, librevenge::RVNG_SEEK_SET);
   f << "Entries(FontsName):";
-  int N=static_cast<int>(m_input->readULong(2));
+  auto N=static_cast<int>(m_input->readULong(2));
   if (3*N+2 > sz) {
     MWAW_DEBUG_MSG(("MacWrtProStructures::readFontsName: can not read the number of fonts\n"));
     m_input->seek(endPos, librevenge::RVNG_SEEK_SET);
@@ -1176,10 +1209,10 @@ bool MacWrtProStructures::readFontsName()
   }
 
   for (int ft = 0; ft < N; ++ft) {
-    int fId = static_cast<int>(m_input->readLong(2));
+    auto fId = static_cast<int>(m_input->readLong(2));
     f << "[id=" << fId << ",";
     for (int st = 0; st < 2; ++st) {
-      int sSz = static_cast<int>(m_input->readULong(1));
+      auto sSz = static_cast<int>(m_input->readULong(1));
       if (long(m_input->tell())+sSz > endPos) {
         MWAW_DEBUG_MSG(("MacWrtProStructures::readFontsName: can not read the %d font\n", ft));
         f << "#";
@@ -1215,7 +1248,7 @@ bool MacWrtProStructures::readFontsDef()
   long pos = m_input->tell();
   libmwaw::DebugStream f;
 
-  long sz = long(m_input->readULong(4));
+  auto sz = long(m_input->readULong(4));
   if (sz == 0) {
     ascii().addPos(pos);
     ascii().addNote("_");
@@ -1237,7 +1270,7 @@ bool MacWrtProStructures::readFontsDef()
   }
   m_input->seek(pos+4, librevenge::RVNG_SEEK_SET);
   f << "Entries(FontsDef):";
-  int N = int(sz/expectedSize);
+  auto N = int(sz/expectedSize);
   f << "N=" << N;
   ascii().addPos(pos);
   ascii().addNote(f.str().c_str());
@@ -1269,7 +1302,7 @@ bool MacWrtProStructures::readFont(MacWrtProStructuresInternal::Font &font)
   libmwaw::DebugStream f;
   font = MacWrtProStructuresInternal::Font();
   font.m_values[0] = static_cast<int>(m_input->readLong(2)); // 1, 3 or 6
-  int val = static_cast<int>(m_input->readULong(2));
+  auto val = static_cast<int>(m_input->readULong(2));
   if (val != 0xFFFF)
     font.m_font.setId(val);
   val = static_cast<int>(m_input->readULong(2));
@@ -1277,7 +1310,7 @@ bool MacWrtProStructures::readFont(MacWrtProStructuresInternal::Font &font)
     font.m_font.setSize(float(val)/4.f);
   if (vers >= 1)
     font.m_values[1] = static_cast<int>(m_input->readLong(2));
-  long flag = long(m_input->readULong(2));
+  auto flag = long(m_input->readULong(2));
   uint32_t flags=0;
   if (flag&0x1) flags |= MWAWFont::boldBit;
   if (flag&0x2) flags |= MWAWFont::italicBit;
@@ -1298,7 +1331,7 @@ bool MacWrtProStructures::readFont(MacWrtProStructuresInternal::Font &font)
   if (flag&0x4000) flags |= MWAWFont::lowercaseBit;
   font.m_flags = (flag&0x8080L);
 
-  int color = static_cast<int>(m_input->readULong(1));
+  auto color = static_cast<int>(m_input->readULong(1));
   MWAWColor col;
   if (color != 1 && getColor(color, col))
     font.m_font.setColor(col);
@@ -1307,7 +1340,7 @@ bool MacWrtProStructures::readFont(MacWrtProStructuresInternal::Font &font)
   val = static_cast<int>(m_input->readULong(1)); // always 0x64 (unused?)
   if (val != 0x64) font.m_values[2] = val;
   if (vers == 1) {
-    int lang = static_cast<int>(m_input->readLong(2));
+    auto lang = static_cast<int>(m_input->readLong(2));
     switch (lang) {
     case 0:
       font.m_font.setLanguage("en_US");
@@ -1323,7 +1356,7 @@ bool MacWrtProStructures::readFont(MacWrtProStructuresInternal::Font &font)
       break;
     }
     font.m_token = static_cast<int>(m_input->readLong(2));
-    int spacings = static_cast<int>(m_input->readLong(2));
+    auto spacings = static_cast<int>(m_input->readLong(2));
     if (spacings) {
       if (spacings < -50 || spacings > 100) {
         MWAW_DEBUG_MSG(("MacWrtProStructures::readFont: character spacings seems odd\n"));
@@ -1355,7 +1388,7 @@ bool MacWrtProStructures::readParagraphs()
   libmwaw::DebugStream f;
   int dataSz = version()==0 ? 202 : 192;
 
-  long sz = long(m_input->readULong(4));
+  auto sz = long(m_input->readULong(4));
   if (sz == 0) {
     ascii().addPos(pos);
     ascii().addNote("_");
@@ -1376,7 +1409,7 @@ bool MacWrtProStructures::readParagraphs()
   }
   m_input->seek(pos+4, librevenge::RVNG_SEEK_SET);
   f << "Entries(ParaZone):";
-  int N = int(sz/dataSz);
+  auto N = int(sz/dataSz);
   f << "N=" << N;
   ascii().addPos(pos);
   ascii().addNote(f.str().c_str());
@@ -1384,7 +1417,7 @@ bool MacWrtProStructures::readParagraphs()
   m_state->m_paragraphsList.resize(0);
   for (int n = 0; n < N; ++n) {
     pos = m_input->tell();
-    int val = static_cast<int>(m_input->readLong(2));
+    auto val = static_cast<int>(m_input->readLong(2));
     f.str("");
     f << "Entries(Paragraph)[" << n << "]:";
     if (val) f << "numChar?="<<val <<",";
@@ -1430,8 +1463,7 @@ bool MacWrtProStructures::readParagraph(MacWrtProStructuresInternal::Paragraph &
 
 
   float spacings[3];
-  for (int i = 0; i < 3; ++i)
-    spacings[i] = float(m_input->readLong(4))/65536.f;
+  for (auto &spacing : spacings) spacing = float(m_input->readLong(4))/65536.f;
   for (int i = 0; i < 3; ++i) {
     int dim = vers==0 ? static_cast<int>(m_input->readLong(4)) : static_cast<int>(m_input->readULong(1));
     bool inPoint = true;
@@ -1512,7 +1544,7 @@ bool MacWrtProStructures::readParagraph(MacWrtProStructuresInternal::Paragraph &
   for (int i = 0; i < 20; ++i) {
     pos = m_input->tell();
     MWAWTabStop newTab;
-    int type = static_cast<int>(m_input->readULong(1));
+    auto type = static_cast<int>(m_input->readULong(1));
     switch (type & 3) {
     case 0:
       break;
@@ -1532,7 +1564,7 @@ bool MacWrtProStructures::readParagraph(MacWrtProStructuresInternal::Paragraph &
       MWAW_DEBUG_MSG(("MacWrtProStructures::readParagraph: tab type is odd\n"));
       f << "tabs" << i << "[#type]=" << std::hex << (type & 0xFc) << std::dec << ",";
     }
-    int leader = static_cast<int>(m_input->readULong(1));
+    auto leader = static_cast<int>(m_input->readULong(1));
     if (leader != 0x20)
       newTab.m_leaderCharacter = static_cast<uint16_t>(leader);
     unsigned long tabPos = m_input->readULong(4);
@@ -1546,7 +1578,7 @@ bool MacWrtProStructures::readParagraph(MacWrtProStructuresInternal::Paragraph &
       f << "tab" << i << "#";
     }
     newTab.m_position = double(tabPos)/72./65536.;
-    int decimalChar = static_cast<int>(m_input->readULong(1));
+    auto decimalChar = static_cast<int>(m_input->readULong(1));
     if (decimalChar && decimalChar != '.')
       newTab.m_decimalCharacter=static_cast<uint16_t>(decimalChar);
     val = static_cast<int>(m_input->readLong(1)); // always 0?
@@ -1577,7 +1609,7 @@ bool MacWrtProStructures::readCharStyles()
   int N;
   int expectedSz = 0x42;
   if (version() == 1) {
-    long sz = long(m_input->readULong(4));
+    auto sz = long(m_input->readULong(4));
     if ((sz%0x42) != 0) {
       MWAW_DEBUG_MSG(("MacWrtProStructures::readCharStyles: find an odd value for sz=%ld\n",sz));
       m_input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -1613,7 +1645,7 @@ bool MacWrtProStructures::readCharStyles()
     pos = m_input->tell();
     f.str("");
     f << "CharStyles-" << i << ":";
-    int sSz = static_cast<int>(m_input->readULong(1));
+    auto sSz = static_cast<int>(m_input->readULong(1));
     if (sSz > 31) {
       MWAW_DEBUG_MSG(("MacWrtProStructures::readCharStyles: string size seems odd\n"));
       sSz = 31;
@@ -1626,7 +1658,7 @@ bool MacWrtProStructures::readCharStyles()
     m_input->seek(pos+32, librevenge::RVNG_SEEK_SET);
 
     if (vers == 1) {
-      int val = static_cast<int>(m_input->readLong(2));
+      auto val = static_cast<int>(m_input->readLong(2));
       if (val) f << "unkn0=" << val << ",";
       val = static_cast<int>(m_input->readLong(2));
       if (val != -1) f << "unkn1=" << val << ",";
@@ -1660,13 +1692,13 @@ bool MacWrtProStructures::readStyles()
 {
   long pos = m_input->tell();
   libmwaw::DebugStream f;
-  long sz = long(m_input->readULong(4));
+  auto sz = long(m_input->readULong(4));
   if ((sz%0x106) != 0) {
     MWAW_DEBUG_MSG(("MacWrtProStructures::readStyles: find an odd value for sz=%ld\n",sz));
     m_input->seek(pos, librevenge::RVNG_SEEK_SET);
     return false;
   }
-  int N = int(sz/0x106);
+  auto N = int(sz/0x106);
 
   if (N==0) {
     ascii().addPos(pos);
@@ -1713,7 +1745,7 @@ bool MacWrtProStructures::readStyle(int styleId)
 
   m_input->seek(pos, librevenge::RVNG_SEEK_SET);
   f << "Style-" << styleId << ":";
-  int strlen = static_cast<int>(m_input->readULong(1));
+  auto strlen = static_cast<int>(m_input->readULong(1));
   if (!strlen || strlen > 31) {
     MWAW_DEBUG_MSG(("MacWrtProStructures::readStyle: style name length seems bad!!\n"));
     m_input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -1807,7 +1839,7 @@ bool MacWrtProStructures::readBlocksList()
   }
   m_input->seek(pos, librevenge::RVNG_SEEK_SET);
   f << "Entries(Block):";
-  int N= static_cast<int>(m_input->readLong(4)); // 1 or 3
+  auto N= static_cast<int>(m_input->readLong(4)); // 1 or 3
   f << "N?=" << N << ",";
   long val = m_input->readLong(4); // 0 or small number 1|fe 72, 529
   if (val) f << "f0=" << val << ",";
@@ -1846,7 +1878,7 @@ bool MacWrtProStructures::readBlocksList()
     ascii().addNote(f.str().c_str());
     m_input->seek(sz, librevenge::RVNG_SEEK_CUR);
   }
-  shared_ptr<MacWrtProStructuresInternal::Block> block;
+  std::shared_ptr<MacWrtProStructuresInternal::Block> block;
   while (1) {
     block = readBlock();
     if (!block) break;
@@ -1874,12 +1906,12 @@ int MacWrtProStructures::getEndBlockSize()
   return sz;
 }
 
-shared_ptr<MacWrtProStructuresInternal::Block>  MacWrtProStructures::readBlockV2(int wh)
+std::shared_ptr<MacWrtProStructuresInternal::Block>  MacWrtProStructures::readBlockV2(int wh)
 {
   long pos = m_input->tell();
   long endPos = pos+76;
   libmwaw::DebugStream f;
-  shared_ptr<MacWrtProStructuresInternal::Block> res;
+  std::shared_ptr<MacWrtProStructuresInternal::Block> res;
 
   m_input->seek(endPos, librevenge::RVNG_SEEK_SET);
   if (long(m_input->tell()) != endPos) {
@@ -1888,7 +1920,7 @@ shared_ptr<MacWrtProStructuresInternal::Block>  MacWrtProStructures::readBlockV2
   }
   m_input->seek(pos, librevenge::RVNG_SEEK_SET);
   long val;
-  int type = static_cast<int>(m_input->readULong(1));
+  auto type = static_cast<int>(m_input->readULong(1));
   res.reset(new MacWrtProStructuresInternal::Block);
   res->m_contentType = MacWrtProStructuresInternal::Block::TEXT;
 
@@ -1896,7 +1928,7 @@ shared_ptr<MacWrtProStructuresInternal::Block>  MacWrtProStructures::readBlockV2
     f << "type=3,";
     val = m_input->readLong(1);
     if (val) f<< "unkn=" << val << ",";
-    int what = static_cast<int>(m_input->readULong(1));
+    auto what = static_cast<int>(m_input->readULong(1));
     switch (what &0xF0) {
     case 0x40: // a header zone
       res->m_isHeader = true;
@@ -1934,7 +1966,7 @@ shared_ptr<MacWrtProStructuresInternal::Block>  MacWrtProStructures::readBlockV2
       return res;
     }
 
-    int id = static_cast<int>(m_input->readLong(2));  // small number, id ?
+    auto id = static_cast<int>(m_input->readLong(2));  // small number, id ?
     if (id) f << "id=" << id << ",";
     val = m_input->readLong(1); // always -1 ?
     if (val != -1) f << "f2=" << val << ",";
@@ -1968,8 +2000,7 @@ shared_ptr<MacWrtProStructuresInternal::Block>  MacWrtProStructures::readBlockV2
   res->m_fileBlock = static_cast<int>(m_input->readULong(2));
 
   float dim[4];
-  for (int i = 0; i < 4; ++i)
-    dim[i] = float(m_input->readLong(2));
+  for (auto &d : dim) d = float(m_input->readLong(2));
   res->m_box = MWAWBox2f(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2]));
   for (int i = 0; i < 4; ++i) { // 8000*4 ?
     val = long(m_input->readULong(i==3 ? 1 : 2));
@@ -2005,27 +2036,27 @@ shared_ptr<MacWrtProStructuresInternal::Block>  MacWrtProStructures::readBlockV2
   return res;
 }
 
-shared_ptr<MacWrtProStructuresInternal::Block> MacWrtProStructures::readBlock()
+std::shared_ptr<MacWrtProStructuresInternal::Block> MacWrtProStructures::readBlock()
 {
   long pos = m_input->tell();
   libmwaw::DebugStream f;
 
-  long sz = long(m_input->readULong(4));
+  auto sz = long(m_input->readULong(4));
   // pat2*3?, dim[pt*65536], border[pt*65536], ?, [0|10|1c], 0, block?
   if (sz < 0x40) {
     m_input->seek(pos, librevenge::RVNG_SEEK_SET);
-    return shared_ptr<MacWrtProStructuresInternal::Block>();
+    return std::shared_ptr<MacWrtProStructuresInternal::Block>();
   }
 
   long endPos = pos+sz+4;
   m_input->seek(endPos, librevenge::RVNG_SEEK_SET);
   if (long(m_input->tell()) != endPos) {
     m_input->seek(pos, librevenge::RVNG_SEEK_SET);
-    return shared_ptr<MacWrtProStructuresInternal::Block>();
+    return std::shared_ptr<MacWrtProStructuresInternal::Block>();
   }
   m_input->seek(pos+4, librevenge::RVNG_SEEK_SET);
 
-  shared_ptr<MacWrtProStructuresInternal::Block> block(new MacWrtProStructuresInternal::Block);
+  std::shared_ptr<MacWrtProStructuresInternal::Block> block(new MacWrtProStructuresInternal::Block);
   long val;
   f << "pat?=[" << std::hex;
   for (int i = 0; i < 2; ++i)
@@ -2033,13 +2064,12 @@ shared_ptr<MacWrtProStructuresInternal::Block> MacWrtProStructures::readBlock()
   f << std::dec << "],";
   block->m_type = static_cast<int>(m_input->readULong(2));
   float dim[4];
-  for (int i = 0; i < 4; ++i)
-    dim[i] = float(m_input->readLong(4))/65536.f;
+  for (auto &d : dim) d = float(m_input->readLong(4))/65536.f;
   block->m_box = MWAWBox2f(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2]));
 
   static int const(wh[4])= { libmwaw::Top, libmwaw::Left, libmwaw::Bottom, libmwaw::Right };
-  for (int i = 0; i < 4; ++i)
-    block->m_borderWList[wh[i]]=double(m_input->readLong(4))/65536.;
+  for (auto what : wh)
+    block->m_borderWList[what]=double(m_input->readLong(4))/65536.;
 
   /* 4: pagebreak,
      5: text
@@ -2065,8 +2095,8 @@ shared_ptr<MacWrtProStructuresInternal::Block> MacWrtProStructures::readBlock()
     if (val) f << "f" << i << "=" << val << ",";
   }
   block->m_baseline = float(m_input->readLong(4))/65536.f;
-  int colorId = static_cast<int>(m_input->readLong(2));
-  int patId=static_cast<int>(m_input->readLong(2));
+  auto colorId = static_cast<int>(m_input->readLong(2));
+  auto patId=static_cast<int>(m_input->readLong(2));
   MWAWColor color(MWAWColor::white());
   if (getColor(colorId, patId, color))
     block->m_surfaceColor = color;
@@ -2088,7 +2118,7 @@ shared_ptr<MacWrtProStructuresInternal::Block> MacWrtProStructures::readBlock()
   val = m_input->readLong(2);
   if (!m_state->updateLineType(static_cast<int>(val), block->m_lineBorder))
     f << "#line[type]=" << val << ",";
-  int contentType = static_cast<int>(m_input->readULong(1));
+  auto contentType = static_cast<int>(m_input->readULong(1));
   switch (contentType) {
   case 0:
     block->m_contentType = MacWrtProStructuresInternal::Block::TEXT;
@@ -2123,9 +2153,9 @@ shared_ptr<MacWrtProStructuresInternal::Block> MacWrtProStructures::readBlock()
     isNote = val==0 || val==0x100;
     if (isNote) {
       float dim2[4];
-      for (int i = 0; i < 4; ++i) {
-        dim2[i] = float(m_input->readLong(4))/65536.f;
-        if (!val && (dim2[i]<0||dim2[i]>0)) {
+      for (auto &d : dim2) {
+        d = float(m_input->readLong(4))/65536.f;
+        if (!val && (d<0||d>0)) {
           isNote = false;
           break;
         }
@@ -2282,7 +2312,7 @@ bool MacWrtProStructures::readSections(std::vector<MacWrtProStructuresInternal::
   long pos = m_input->tell();
   libmwaw::DebugStream f;
 
-  long sz = long(m_input->readULong(4));
+  auto sz = long(m_input->readULong(4));
   if (sz == 0) {
     ascii().addPos(pos);
     ascii().addNote("_");
@@ -2301,7 +2331,7 @@ bool MacWrtProStructures::readSections(std::vector<MacWrtProStructuresInternal::
     return true;
   }
 
-  int N = int(sz/0xd8);
+  auto N = int(sz/0xd8);
   f << "Entries(Section):";
   f << "N=" << N;
   ascii().addPos(pos);
@@ -2314,7 +2344,7 @@ bool MacWrtProStructures::readSections(std::vector<MacWrtProStructuresInternal::
     sec.m_textLength = long(m_input->readULong(4));
     long val =  m_input->readLong(4); // almost always 0 or a dim?
     if (val) f << "dim?=" << float(val)/65536.f << ",";
-    int startWay = static_cast<int>(m_input->readLong(2));
+    auto startWay = static_cast<int>(m_input->readLong(2));
     switch (startWay) {
     case 1:
       sec.m_start = sec.S_Line;
@@ -2349,7 +2379,7 @@ bool MacWrtProStructures::readSections(std::vector<MacWrtProStructuresInternal::
       val = long(m_input->readULong(1));
       if (val) f << "fl" << st+2 << "=" << std::hex << val << std::dec << ",";
     }
-    int numColumns = static_cast<int>(m_input->readLong(2));
+    auto numColumns = static_cast<int>(m_input->readLong(2));
     if (numColumns < 1 || numColumns > 20) {
       MWAW_DEBUG_MSG(("MacWrtProStructures::readSections: bad number of columns\n"));
       f << "#nCol=" << numColumns << ",";
@@ -2413,7 +2443,7 @@ bool MacWrtProStructures::readSelection()
   }
   m_input->seek(pos, librevenge::RVNG_SEEK_SET);
   f << "Entries(Selection):";
-  int val = static_cast<int>(m_input->readLong(2));
+  auto val = static_cast<int>(m_input->readLong(2));
   f << "f0=" << val << ","; // zone?
   val = static_cast<int>(m_input->readLong(4)); // -1, 0 or 8 : zone type?
   if (val == -1 || val == 0) { // checkme: none ?
@@ -2443,7 +2473,7 @@ bool MacWrtProStructures::readString(MWAWInputStreamPtr input, std::string &res)
 {
   res="";
   long pos = input->tell();
-  int sz = static_cast<int>(input->readLong(2));
+  auto sz = static_cast<int>(input->readLong(2));
   if (sz == 0) return true;
   if (sz < 0) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -2456,7 +2486,7 @@ bool MacWrtProStructures::readString(MWAWInputStreamPtr input, std::string &res)
     return false;
   }
   for (int i= 0; i < sz; ++i) {
-    char c = char(input->readULong(1));
+    auto c = char(input->readULong(1));
     if (c) {
       res+=c;
       continue;
@@ -2477,7 +2507,7 @@ bool MacWrtProStructures::readStructB()
   long pos = m_input->tell();
   libmwaw::DebugStream f;
 
-  int N = static_cast<int>(m_input->readULong(2));
+  auto N = static_cast<int>(m_input->readULong(2));
   if (N==0) {
     ascii().addPos(pos);
     ascii().addNote("_");
@@ -2492,7 +2522,7 @@ bool MacWrtProStructures::readStructB()
     m_input->seek(pos, librevenge::RVNG_SEEK_SET);
     return false;
   }
-  int val = static_cast<int>(m_input->readULong(2));
+  auto val = static_cast<int>(m_input->readULong(2));
   if (val != 0x2af8)
     f << "f0=" << std::hex << val << std::dec << ",";
   val = static_cast<int>(m_input->readULong(2));
@@ -2536,7 +2566,7 @@ bool MacWrtProStructures::isSent(int blockId)
 bool MacWrtProStructures::send(int blockId, bool mainZone)
 {
   MWAWTextListenerPtr listener=m_parserState->m_textListener;
-  shared_ptr<MacWrtProStructuresInternal::Block> block;
+  std::shared_ptr<MacWrtProStructuresInternal::Block> block;
   if (version()==0) {
     if (blockId < 0) {
       if (-blockId > int(m_state->m_footnotesList.size())) {
@@ -2593,8 +2623,7 @@ bool MacWrtProStructures::send(int blockId, bool mainZone)
         m_mainParser.sendTextBoxZone(blockId, block->getPosition());
       }
       else {
-        shared_ptr<MacWrtProStructuresInternal::Table> table =
-          m_state->m_tablesMap.find(blockId)->second;
+        auto table = m_state->m_tablesMap.find(blockId)->second;
         if (!table->sendTable(listener))
           table->sendAsText(listener);
         block->m_textboxCellType = 0;
@@ -2629,46 +2658,53 @@ void MacWrtProStructures::flushExtra()
   }
   // first send the text
   for (size_t i = 0; i < m_state->m_blocksList.size(); ++i) {
-    if (m_state->m_blocksList[i]->m_send)
+    auto block = m_state->m_blocksList[i];
+    if (block->m_send)
       continue;
-    if (m_state->m_blocksList[i]->m_type == 6) {
+    if (block->m_type == 6) {
       /* Fixme: macwritepro can have one header/footer by page and one by default.
          For the moment, we only print the first one :-~ */
       MWAW_DEBUG_MSG(("MacWrtProStructures::flushExtra: find some header/footer\n"));
       continue;
     }
-    int id = vers == 0 ? int(i) : m_state->m_blocksList[i]->m_id;
-    if (m_state->m_blocksList[i]->isText()) {
+    int id = vers == 0 ? int(i) : block->m_id;
+    if (block->isText()) {
       // force to non floating position
-      m_state->m_blocksList[i]->m_attachment = true;
+      block->m_attachment = true;
       send(id);
       if (listener) listener->insertEOL();
     }
-    else if (m_state->m_blocksList[i]->m_type == 3) {
+    else if (block->m_type == 3) {
       // force to non floating position
-      m_state->m_blocksList[i]->m_attachment = true;
+      block->m_attachment = true;
       send(id);
     }
   }
   // then send graphic
-  for (size_t i = 0; i < m_state->m_blocksList.size(); ++i) {
-    if (m_state->m_blocksList[i]->m_send)
+  for (auto block : m_state->m_blocksList) {
+    if (block->m_send)
       continue;
-    if (m_state->m_blocksList[i]->isGraphic()) {
+    if (block->isGraphic()) {
       // force to non floating position
-      m_state->m_blocksList[i]->m_attachment = true;
-      send(m_state->m_blocksList[i]->m_id);
+      block->m_attachment = true;
+      send(block->m_id);
     }
   }
 }
 
 ////////////////////////////////////////////////////////////
 // interface with the listener
-MacWrtProStructuresListenerState::MacWrtProStructuresListenerState(shared_ptr<MacWrtProStructures> structures, bool mainZone)
-  : m_isMainZone(mainZone), m_actPage(0), m_actTab(0), m_numTab(0),
-    m_section(0), m_numCols(1), m_newPageDone(false), m_structures(structures),
-    m_font(new MacWrtProStructuresInternal::Font),
-    m_paragraph(new MacWrtProStructuresInternal::Paragraph)
+MacWrtProStructuresListenerState::MacWrtProStructuresListenerState(std::shared_ptr<MacWrtProStructures> const &structures, bool mainZone)
+  : m_isMainZone(mainZone)
+  , m_actPage(0)
+  , m_actTab(0)
+  , m_numTab(0)
+  , m_section(0)
+  , m_numCols(1)
+  , m_newPageDone(false)
+  , m_structures(structures)
+  , m_font(new MacWrtProStructuresInternal::Font)
+  , m_paragraph(new MacWrtProStructuresInternal::Paragraph)
 {
   if (!m_structures) {
     MWAW_DEBUG_MSG(("MacWrtProStructuresListenerState::MacWrtProStructuresListenerState can not find structures parser\n"));
@@ -2712,8 +2748,7 @@ bool MacWrtProStructuresListenerState::newPage(bool softBreak)
 
   // first send all the floating data
   if (m_actPage == 0) {
-    for (size_t i = 0; i < m_structures->m_state->m_blocksList.size(); ++i) {
-      shared_ptr<MacWrtProStructuresInternal::Block> block = m_structures->m_state->m_blocksList[i];
+    for (auto block : m_structures->m_state->m_blocksList) {
       if (block->m_send || block->m_attachment) continue;
       if (block->m_type != 3 && block->m_type != 4 && block->m_type != 8) continue;
       m_structures->send(block->m_id);
@@ -2731,8 +2766,7 @@ std::vector<int> MacWrtProStructuresListenerState::getPageBreaksPos() const
 {
   std::vector<int> res;
   if (!m_structures || !m_isMainZone) return res;
-  for (size_t i = 0; i < m_structures->m_state->m_blocksList.size(); ++i) {
-    shared_ptr<MacWrtProStructuresInternal::Block> block = m_structures->m_state->m_blocksList[i];
+  for (auto block : m_structures->m_state->m_blocksList) {
     if (block->m_type != 5) continue;
     if (block->m_textPos) res.push_back(block->m_textPos);
   }
@@ -2937,8 +2971,7 @@ void MacWrtProStructuresListenerState::sendSection(int nSection)
     MWAW_DEBUG_MSG(("MacWrtProStructuresListenerState::sendSection: can not find section %d\n", nSection));
     return;
   }
-  MacWrtProStructuresInternal::Section const &section =
-    m_structures->m_state->m_sectionsList[size_t(nSection)];
+  auto const &section = m_structures->m_state->m_sectionsList[size_t(nSection)];
   if (nSection && section.m_start != section.S_Line) newPage();
 
   listener->openSection(section.getSection());
