@@ -156,7 +156,7 @@ MWAWSection Section::getSection(double pageWidth) const
   MWAWSection::Column col;
   col.m_width=pageWidth/double(numCols);
   col.m_widthUnit=librevenge::RVNG_INCH;
-  col.m_margins[libmwaw::Left] = col.m_margins[libmwaw::Right] = *m_colSep/2.;
+  col.m_margins[libmwaw::Left] = col.m_margins[libmwaw::Right] = double(*m_colSep)/2.;
   sec.m_columns.resize(size_t(numCols), col);
   sec.m_columns[0].m_margins[libmwaw::Left] = 0;
   sec.m_columns[size_t(numCols-1)].m_margins[libmwaw::Right] = 0;
@@ -170,11 +170,11 @@ bool Section::read(MWAWInputStreamPtr &input, long endPos)
   long dSz = endPos-pos;
   if (dSz < 1) return false;
   libmwaw::DebugStream f;
-  int c = (int) input->readULong(1), val;
+  int c = static_cast<int>(input->readULong(1)), val;
   switch (c) {
   case 0x75: // column break
     if (dSz < 2) return false;
-    val = (int) input->readLong(1);
+    val = static_cast<int>(input->readLong(1));
     switch (val) {
     case 0:
       m_colBreak = false;
@@ -189,7 +189,7 @@ bool Section::read(MWAWInputStreamPtr &input, long endPos)
     break;
   case 0x77: // num column
     if (dSz<3) return false;
-    m_col = (int) input->readLong(2)+1;
+    m_col = static_cast<int>(input->readLong(2))+1;
     return true;
   case 0x78:
     if (dSz<3) return false;
@@ -218,7 +218,7 @@ bool Section::read(MWAWInputStreamPtr &input, long endPos)
   case 0x83:
   case 0x84:
     if (dSz < 3) return false;
-    val = (int) input->readLong(2);
+    val = static_cast<int>(input->readLong(2));
     if (c == 0x83) f << "header[top]=" << val/1440. << ",";
     else f << "header[bottom]=" << val/1440. << ",";
     break;
@@ -236,11 +236,11 @@ bool Section::readV3(MWAWInputStreamPtr &input, long endPos)
   long dSz = endPos-pos;
   if (dSz < 1) return false;
   libmwaw::DebugStream f;
-  int wh = (int) input->readULong(1), val;
+  int wh = static_cast<int>(input->readULong(1)), val;
   switch (wh) {
   case 0x36:
     if (dSz < 2) return false;
-    val = (int) input->readLong(1);
+    val = static_cast<int>(input->readLong(1));
     switch (val) {
     case 0:
       f << "division=no,";
@@ -264,7 +264,7 @@ bool Section::readV3(MWAWInputStreamPtr &input, long endPos)
     break;
   case 0x37:
     if (dSz < 2) return false;
-    val = (int) input->readLong(1);
+    val = static_cast<int>(input->readLong(1));
     switch (val) {
     case 0:
       break; // no front page
@@ -278,7 +278,7 @@ bool Section::readV3(MWAWInputStreamPtr &input, long endPos)
     break;
   case 0x3a:
     if (dSz < 2) return false;
-    val = (int) input->readLong(1);
+    val = static_cast<int>(input->readLong(1));
     switch (val) {
     case 1:
       f << "addNumbering,";
@@ -290,7 +290,7 @@ bool Section::readV3(MWAWInputStreamPtr &input, long endPos)
     break;
   case 0x3b:
     if (dSz < 2) return false;
-    val = (int) input->readLong(1);
+    val = static_cast<int>(input->readLong(1));
     switch (val) {
     case 1:
       f << "numbering=arabic,";
@@ -314,7 +314,7 @@ bool Section::readV3(MWAWInputStreamPtr &input, long endPos)
     break;
   case 0x3e:
     if (dSz < 2) return false;
-    val = (int) input->readLong(1);
+    val = static_cast<int>(input->readLong(1));
     switch (val) {
     case 1:
       f << "newNumber=byPage,";
@@ -326,7 +326,7 @@ bool Section::readV3(MWAWInputStreamPtr &input, long endPos)
     break;
   case 0x3f:
     if (dSz < 2) return false;
-    val = (int) input->readLong(1);
+    val = static_cast<int>(input->readLong(1));
     switch (val) {
     case 0:
       f << "footnote,";
@@ -341,7 +341,7 @@ bool Section::readV3(MWAWInputStreamPtr &input, long endPos)
     break;
   case 0x40:
     if (dSz < 2) return false;
-    val = (int) input->readLong(1);
+    val = static_cast<int>(input->readLong(1));
     switch (val) {
     case 1:
       f << "numberline=byDivision,";
@@ -356,7 +356,7 @@ bool Section::readV3(MWAWInputStreamPtr &input, long endPos)
     break;
   case 0x41: // 8 or a
     if (dSz < 2) return false;
-    val = (int) input->readLong(1);
+    val = static_cast<int>(input->readLong(1));
     f << "f41=" << std::hex << val << std::dec << ",";
     break;
   case 0x38:
@@ -368,10 +368,10 @@ bool Section::readV3(MWAWInputStreamPtr &input, long endPos)
   case 0x44:
   case 0x45:
     if (dSz < 3) return false;
-    val = (int) input->readLong(2);
+    val = static_cast<int>(input->readLong(2));
     switch (wh) {
     case 0x38:
-      m_col = (int)val+1;
+      m_col = static_cast<int>(val)+1;
       break;
     case 0x42:
       f << "numberline[lines]=" << val << ",";
@@ -424,9 +424,8 @@ std::ostream &operator<<(std::ostream &o, Section const &section)
 MWAWVariable<Table::Cell> &Table::getCell(int id)
 {
   if (id < 0) {
-    static MWAWVariable<Table::Cell> badCell;
     MWAW_DEBUG_MSG(("MsWrdStruct::Table::getCell: can not return a negative cell id\n"));
-    return badCell;
+    return m_badCell;
   }
   if (m_cells.size() <= size_t(id)) m_cells.resize(size_t(id)+1);
   return m_cells[size_t(id)];
@@ -438,12 +437,12 @@ bool Table::read(MWAWInputStreamPtr &input, long endPos)
   long dSz = endPos-pos;
   if (dSz < 1) return false;
   libmwaw::DebugStream f, f2;
-  int c = (int) input->readULong(1), val;
+  int c = static_cast<int>(input->readULong(1)), val;
   switch (c) {
   case 0x98: { // tabs columns
-    int sz = (int) input->readULong(2);
+    auto sz = static_cast<int>(input->readULong(2));
     if (!sz || dSz < 2+sz) return false;
-    int N = (int) input->readULong(1);
+    auto N = static_cast<int>(input->readULong(1));
     if (1+(N+1)*2 > sz) {
       MWAW_DEBUG_MSG(("MsWrdStruct::Table::read: table definition seems odd\n"));
       f << "#colDef";
@@ -458,7 +457,7 @@ bool Table::read(MWAWInputStreamPtr &input, long endPos)
       int numElt= (N1-10*i)/2;
       if (numElt>5) numElt=5;
       f2.str("");
-      val = (int) input->readULong(2);
+      val = static_cast<int>(input->readULong(2));
       switch (val) {
       case 0:
         break;
@@ -475,14 +474,13 @@ bool Table::read(MWAWInputStreamPtr &input, long endPos)
         cell.m_borders.resize(size_t(numElt)-1);
         for (int b = 0; b < numElt-1; b++) {
           std::string bExtra;
-          MWAWBorder border = getBorder((int) input->readULong(2), bExtra);
-          cell.m_borders[size_t(b)] = border;
+          cell.m_borders[size_t(b)] = getBorder(static_cast<int>(input->readULong(2)), bExtra);
           if (bExtra.length())
             f2 << "#bord" << b << "=" << bExtra << ",";
         }
       }
       cell.m_extra = f2.str();
-      m_cells.push_back(cell);
+      m_cells.push_back(MWAWVariable<Cell>(cell));
       m_cells.back().setSet(true);
     }
     input->seek(pos+2+sz, librevenge::RVNG_SEEK_SET);
@@ -490,7 +488,7 @@ bool Table::read(MWAWInputStreamPtr &input, long endPos)
   }
   case 0x92: // table alignment
     if (dSz < 3) return false;
-    val = (int) input->readULong(2);
+    val = static_cast<int>(input->readULong(2));
     switch (val&3) {
     case 0:
       m_justify = MWAWParagraph::JustificationLeft;
@@ -519,7 +517,7 @@ bool Table::read(MWAWInputStreamPtr &input, long endPos)
     return true;
   case 0x9a: { // the table shading
     if (dSz < 2) return false;
-    int sz = (int) input->readULong(1);
+    auto sz = static_cast<int>(input->readULong(1));
     if (2+sz > dSz || (sz%2)) return false;
     for (int i = 0; i < sz/2; i++) {
       float backColor=1.f-float(input->readULong(2))/10000.f;
@@ -529,10 +527,10 @@ bool Table::read(MWAWInputStreamPtr &input, long endPos)
   }
   case 0x9d: { // table cell shading
     if (dSz < 6) return false;
-    val = (int) input->readLong(1); // a small number often 4
+    val = static_cast<int>(input->readLong(1)); // a small number often 4
     if (val!=4) f << "backColor[unkn?]=" << val << ",";
-    int firstCol = (int) input->readLong(1);
-    int lastCol = (int) input->readLong(1);
+    auto firstCol = static_cast<int>(input->readLong(1));
+    auto lastCol = static_cast<int>(input->readLong(1));
     if (firstCol < 0 || lastCol < 0 || firstCol+1 > lastCol) {
       input->seek(2, librevenge::RVNG_SEEK_CUR);
       MWAW_DEBUG_MSG(("MsWrdStruct::Table::read: pb for background range\n"));
@@ -546,8 +544,8 @@ bool Table::read(MWAWInputStreamPtr &input, long endPos)
   }
   case 0xa0: { // table dimension modifier
     if (dSz < 5) return false;
-    int firstCol = (int) input->readULong(1);
-    int lastCol = (int) input->readULong(1);
+    auto firstCol = static_cast<int>(input->readULong(1));
+    auto lastCol = static_cast<int>(input->readULong(1));
     float dim=float(input->readLong(2))/20.0f;
     f << "col[widthMod" << firstCol << "<->" << lastCol-1 << "]=" << dim<< ",";
     if (m_columnsWidthMod->size()<=size_t(firstCol))
@@ -558,8 +556,8 @@ bool Table::read(MWAWInputStreamPtr &input, long endPos)
   case 0xa3: {
     if (dSz < 6) return false;
     // range 0: means A1
-    int firstCol = (int) input->readLong(1);
-    int lastCol = (int) input->readLong(1);
+    auto firstCol = static_cast<int>(input->readLong(1));
+    auto lastCol = static_cast<int>(input->readLong(1));
     if (firstCol < 0 || lastCol < 0 || firstCol+1 > lastCol) {
       input->seek(3, librevenge::RVNG_SEEK_CUR);
       MWAW_DEBUG_MSG(("MsWrdStruct::Table::read: pb for mod color\n"));
@@ -574,7 +572,7 @@ bool Table::read(MWAWInputStreamPtr &input, long endPos)
     if (val & 8) maxVal = 4;
     if (val&0xF0) f << "borderMod[wh=#" << std::hex << int(val&0xF0) << std::dec << "],";
     std::string bExtra;
-    MWAWBorder border = getBorder((int) input->readULong(2), bExtra);
+    MWAWBorder border = getBorder(static_cast<int>(input->readULong(2)), bExtra);
     for (int i = firstCol; i < lastCol; i++) {
       MWAWVariable<Cell> &cell = getCell(i);
       if (cell->m_borders.size() < maxVal)
@@ -669,16 +667,18 @@ std::ostream &operator<<(std::ostream &o, Table const &table)
     case MWAWParagraph::JustificationFullAllLines:
       o << "just=fullAllLines, ";
       break;
+#if !defined(__clang__)
     default:
       o << "just=" << table.m_justify.get() << ", ";
       break;
+#endif
     }
   }
   if (table.m_indent.isSet()) o << "indent=" << table.m_indent.get() << ",";
   if (table.m_columns.isSet() && table.m_columns->size()) {
     o << "cols=[";
-    for (size_t i = 0; i < table.m_columns->size(); i++)
-      o << table.m_columns.get()[i] << ",";
+    for (auto const &col : table.m_columns.get())
+      o << col << ",";
     o << "],";
   }
   if (table.m_columnsWidthMod.isSet() && table.m_columnsWidthMod->size()) {
@@ -687,16 +687,10 @@ std::ostream &operator<<(std::ostream &o, Table const &table)
         o << "col" << i << "[width]=" << (*table.m_columnsWidthMod)[i] << ",";
     }
   }
-  if (table.m_columns->size()) {
-    o << "cols=[";
-    for (size_t i = 0; i < table.m_columns->size(); i++)
-      o << table.m_columns.get()[i] << ",";
-    o << "],";
-  }
   if (table.m_cells.size()) {
     o << "cells=[";
-    for (size_t i = 0; i < table.m_cells.size(); i++)
-      o << "[" << table.m_cells[i].get() << "],";
+    for (auto const &cell : table.m_cells)
+      o << "[" << cell.get() << "],";
     o << "],";
   }
   if (table.m_extra.length()) o << table.m_extra;
@@ -711,8 +705,8 @@ bool ParagraphInfo::read(MWAWInputStreamPtr &input, long endPos, int vers)
     MWAW_DEBUG_MSG(("ParagraphInfo::read: zone is too short\n"));
     return false;
   }
-  m_type = (int) input->readULong(1); // 0, 20(then ff), 40, 60(then ff)
-  m_numLines = (int) input->readLong(1);
+  m_type = static_cast<int>(input->readULong(1)); // 0, 20(then ff), 40, 60(then ff)
+  m_numLines = static_cast<int>(input->readLong(1));
   if (vers <= 3)
     return true;
   m_dim->setX(float(input->readULong(2))/1440.f);
@@ -728,6 +722,10 @@ void ParagraphInfo::insert(ParagraphInfo const &pInfo)
 }
 
 // paragraph
+Paragraph::~Paragraph()
+{
+}
+
 bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
 {
   long pos = input->tell();
@@ -748,15 +746,15 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
   long dSz = endPos-pos;
   if (dSz < 1) return false;
   libmwaw::DebugStream f;
-  int c = (int) input->readULong(1), val;
+  int c = static_cast<int>(input->readULong(1)), val;
   switch (c) {
   case 0x2: // sprmPIstd
     if (dSz < 2) return false;
-    m_styleId = (int) input->readLong(1);
+    m_styleId = static_cast<int>(input->readLong(1));
     break;
   case 0x3: { // sprmPIstdPermute: checkme: alway find with 3,3,2,3
     if (dSz < 2) return false;
-    int num= (int) input->readULong(1);
+    auto num= static_cast<int>(input->readULong(1));
     if (num<=0 || dSz < 2+num) return false;
     MWAW_DEBUG_MSG(("Paragraph::read: find istd permute list, unimplemented\n"));
     f << "istPerm=[";
@@ -767,7 +765,7 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
   }
   case 0x5:
     if (dSz < 2) return false;
-    val = (int) input->readLong(1);
+    val = static_cast<int>(input->readLong(1));
     switch (val) {
     case 0:
       m_justify = MWAWParagraph::JustificationLeft;
@@ -793,7 +791,7 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
   case 0x9:
   case 0xe: // a small number always 0 ?
     if (dSz < 2) return false;
-    val = (int) input->readLong(1);
+    val = static_cast<int>(input->readLong(1));
     switch (c) {
     case 7:
       if (val==0)
@@ -822,7 +820,7 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
     break;
   case 0xa: {
     if (dSz < 2) return false;
-    val = (int) input->readLong(1);
+    val = static_cast<int>(input->readLong(1));
     MWAWBorder border;
     switch (val) {
     case 0:
@@ -846,7 +844,7 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
   }
   case 0xb:
     if (dSz < 2) return false;
-    val = (int) input->readULong(1);
+    val = static_cast<int>(input->readULong(1));
     if (val && val <= 0x10) {
       if (m_borders.size() < 4)
         resizeBorders(4);
@@ -866,13 +864,13 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
     break;
   case 0xf: // tabs
   case 0x17:  { // tabs
-    int sz = (int) input->readULong(1);
+    auto sz = static_cast<int>(input->readULong(1));
     if (sz<2 || 2+sz > dSz) {
       MWAW_DEBUG_MSG(("MsWrdStruct::Paragraph::read: can not read tab\n"));
       return false;
     }
     int deletedSz=(c==0x17) ? 4 : 2;
-    int N0 = (int) input->readULong(1);
+    auto N0 = static_cast<int>(input->readULong(1));
     if (deletedSz*N0 > sz) {
       MWAW_DEBUG_MSG(("MsWrdStruct::Paragraph::read: num of deleted tabs seems odd\n"));
       return false;
@@ -884,7 +882,7 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
     if (c==0x17 && N0) {
       f << "del17=[";
       for (int i = 0; i < N0; i++) { // always with 0x19 ?
-        val=(int) input->readULong(2);
+        val=static_cast<int>(input->readULong(2));
         if (val==0x19)
           f << "_";
         else
@@ -892,7 +890,7 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
       }
       f << "],";
     }
-    int N = (int) input->readULong(1);
+    auto N = static_cast<int>(input->readULong(1));
     if (N*3+deletedSz*N0+2 != sz) {
       MWAW_DEBUG_MSG(("MsWrdStruct::Paragraph::read: num tab seems odd\n"));
       f << "#";
@@ -900,12 +898,12 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
       return false;
     }
     std::vector<float> tabs;
-    tabs.resize((size_t) N);
-    for (int i = 0; i < N; i++) tabs[(size_t) i] = float(input->readLong(2))/1440.f;
-    for (int i = 0; i < N; i++) {
+    tabs.resize(size_t(N));
+    for (auto &t : tabs) t = float(input->readLong(2))/1440.f;
+    for (auto const &tabPos : tabs) {
       MWAWTabStop tab;
-      tab.m_position = tabs[(size_t) i];
-      val = (int) input->readULong(1);
+      tab.m_position = double(tabPos);
+      val = static_cast<int>(input->readULong(1));
       switch (val>>5) {
       case 0:
         break;
@@ -949,26 +947,26 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
   case 0x11: // left
   case 0x13: // first left
     if (dSz < 3) return false;
-    val = (int) input->readLong(2);
+    val = static_cast<int>(input->readLong(2));
     if (c == 0x13) m_margins[0] = val/1440.;
     else if (c == 0x11) m_margins[1] = val/1440.;
     else m_margins[2] = val/1440.;
     return true;
   case 0x14: // alignment : 240 normal, 480 : double, ..
     if (dSz < 3) return false;
-    val = (int) input->readLong(2);
+    val = static_cast<int>(input->readLong(2));
     m_interline=double(val)/1440.;
     return true;
   case 0x15: // spacing before DWIPP
   case 0x16: // spacing after DWIPP
     if (dSz < 3) return false;
-    val = (int) input->readLong(2);
+    val = static_cast<int>(input->readLong(2));
     m_spacings[c-0x14] = double(val)/1440.;
     return true;
   case 0x18:
   case 0x19:
     if (dSz < 2) return false;
-    val = (int) input->readULong(1);
+    val = static_cast<int>(input->readULong(1));
     if (c==0x18) m_inCell = (val!=0);
     else m_tableDef = (val != 0);
     if (val != 0 && val!=1) {
@@ -980,7 +978,7 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
   case 0x1b:
   case 0x1c: {
     if (dSz < 3) return false;
-    val = (int) input->readLong(2);
+    val = static_cast<int>(input->readLong(2));
     char const *what[] = {"frameX", "frameY", "frameWidth" };
     f << what[c-0x1a] << "=";
     if (val < 0) {
@@ -1032,7 +1030,7 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
   }
   case 0x1d:
     if (dSz < 2) return false;
-    val = (int) input->readULong(1);
+    val = static_cast<int>(input->readULong(1));
     switch (val&3) {
     case 0:
       break; // column
@@ -1056,7 +1054,7 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
   case 0x22: {
     if (dSz < 3) return false;
     std::string bExtra;
-    MWAWBorder border = getBorder((int) input->readULong(2), bExtra);
+    MWAWBorder border = getBorder(static_cast<int>(input->readULong(2)), bExtra);
     if (bExtra.length())
       f << "bord" << (c-0x1e) << "[" << bExtra << "],";
     if (c < 0x22) {
@@ -1078,7 +1076,7 @@ bool Paragraph::read(MWAWInputStreamPtr &input, long endPos)
   }
   case 0x24: { // distance to text (related to frame ?)
     if (dSz < 3) return false;
-    val = (int) input->readULong(2);
+    val = static_cast<int>(input->readULong(2));
     if (val) f << "distToText=" << val/1440. << ",";
     break;
   }
@@ -1096,8 +1094,8 @@ std::ostream &operator<<(std::ostream &o, Paragraph const &ind)
     o << "styleId[orig]=" << ind.m_styleId.get() << ",";
   if (!ind.m_deletedTabs.empty()) {
     o << "deletedTab=[";
-    for (size_t i = 0; i < ind.m_deletedTabs.size(); i++)
-      o << ind.m_deletedTabs[i] << ",";
+    for (auto const &val : ind.m_deletedTabs)
+      o << val << ",";
     o << "],";
   }
   if (ind.m_interline.isSet())
@@ -1160,12 +1158,11 @@ void Paragraph::insert(Paragraph const &para, bool insertModif)
   if (m_tabs.isSet()) {
     for (int st=0; st<2; ++st) {
       std::vector<float> const &deletedTabs=st==0?para.m_deletedTabs:m_deletedTabs;
-      for (size_t i = 0; i < deletedTabs.size(); ++i) {
-        float val = deletedTabs[i];
-        for (size_t j = 0; j < m_tabs->size(); j++) {
-          if (m_tabs.get()[j].m_position < val-1e-3 || m_tabs.get()[j].m_position > val+1e-3)
+      for (auto const val : deletedTabs) {
+        for (auto it=m_tabs->begin(); it!=m_tabs->end(); ++it) {
+          if (it->m_position < double(val)-1e-3 || it->m_position > double(val)+1e-3)
             continue;
-          m_tabs->erase(m_tabs->begin()+int(j));
+          m_tabs->erase(it);
           break;
         }
       }
