@@ -53,22 +53,29 @@ RagTime5StructManager::~RagTime5StructManager()
 {
 }
 
+RagTime5StructManager::DataParser::~DataParser()
+{
+}
+
+RagTime5StructManager::FieldParser::~FieldParser()
+{
+}
 ////////////////////////////////////////////////////////////
 // read basic structures
 ////////////////////////////////////////////////////////////
 bool RagTime5StructManager::readCompressedLong(MWAWInputStreamPtr &input, long endPos, long &val)
 {
-  val=(long) input->readULong(1);
+  val=long(input->readULong(1));
   if ((val&0xF0)==0xC0) {
     input->seek(-1, librevenge::RVNG_SEEK_CUR);
-    val=(long)(MWAWInputStream::readULong(input->input().get(), 4, 0, false)&0xFFFFFFF);
+    val=long(MWAWInputStream::readULong(input->input().get(), 4, 0, false)&0xFFFFFFF);
   }
   else if (val>=0xD0) { // never seems, but may be ok
     MWAW_DEBUG_MSG(("RagTime5Struct::readCompressedLong: can not read a long\n"));
     return false;
   }
   else if (val>=0x80)
-    val=((val&0x7F)<<8)+(long) input->readULong(1);
+    val=((val&0x7F)<<8)+long(input->readULong(1));
   return input->tell()<=endPos;
 }
 
@@ -93,14 +100,14 @@ bool RagTime5StructManager::readTypeDefinitions(RagTime5Zone &zone)
   f << "N=" << N << ",";
   int val;
   for (int i=0; i<2; ++i) { // always 0,0
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
-  int sz=(int) input->readULong(1);
+  auto sz=static_cast<int>(input->readULong(1));
   if (sz) {
     f << "data1=[" << std::hex;
     for (int i=0; i<sz+1; ++i) {
-      val=(int) input->readULong(1);
+      val=static_cast<int>(input->readULong(1));
       if (val) f << val << ",";
       else f << "_,";
     }
@@ -113,11 +120,11 @@ bool RagTime5StructManager::readTypeDefinitions(RagTime5Zone &zone)
     return false;
   }
   f << "ptr=[" << std::hex;
-  std::vector<long> listPtrs((size_t)(N+1), -1);
+  std::vector<long> listPtrs(size_t(N+1), -1);
   long lastPtr=0;
   int numOk=0;
   for (size_t i=0; i<=size_t(N); ++i) {
-    long ptr=(long) input->readULong(4);
+    auto ptr=long(input->readULong(4));
     if (ptr<0 || ptr>remain || ptr<lastPtr) {
       f << "###";
       static bool first=true;
@@ -149,7 +156,7 @@ bool RagTime5StructManager::readTypeDefinitions(RagTime5Zone &zone)
     if (listPtrs[i]==remain) break;
     f.str("");
     f << "TypeDef-" << i << "[head]:";
-    int dSz=int(listPtrs[i+1]-listPtrs[i]);
+    auto dSz=int(listPtrs[i+1]-listPtrs[i]);
     long pos=debDataPos+listPtrs[i];
     if (dSz<4+20) {
       f << "###";
@@ -158,9 +165,9 @@ bool RagTime5StructManager::readTypeDefinitions(RagTime5Zone &zone)
       ascFile.addNote(f.str().c_str());
     }
     input->seek(pos, librevenge::RVNG_SEEK_SET);
-    val=(int) input->readLong(4); // a small number
+    val=static_cast<int>(input->readLong(4)); // a small number
     if (val!=1) f << "f0=" << val << ",";
-    int hSz=(int) input->readULong(2);
+    auto hSz=static_cast<int>(input->readULong(2));
     int nData=(dSz-4-hSz)/12;
     if (4+hSz>dSz || dSz!=4+hSz+12*nData || nData<0 || hSz<20) {
       f << "###hSz=" << hSz << ",";
@@ -169,20 +176,20 @@ bool RagTime5StructManager::readTypeDefinitions(RagTime5Zone &zone)
       ascFile.addNote(f.str().c_str());
       continue;
     }
-    val=(int) input->readULong(2);
+    val=static_cast<int>(input->readULong(2));
     if (val) f << "fl=" << std::hex << val << std::dec << ",";
-    val=(int) input->readULong(4);
+    val=static_cast<int>(input->readULong(4));
     if (val) f << "id?=" << std::hex << val << std::dec << ",";
-    long type=(long) input->readULong(4);
+    auto type=long(input->readULong(4));
     if (type) f << "type=" << std::hex << type << std::dec << ",";
     for (int j=0; j<2; ++j) { // f1=0..12,
-      val=(int) input->readLong(2);
+      val=static_cast<int>(input->readLong(2));
       if (val) f << "f" << j+1 << "=" << val << ",";
     }
-    type=(long) input->readULong(4);
-    if (type) f << "type2=" << std::hex << type << std::dec << ",";
+    auto type2=long(input->readULong(4));
+    if (type2) f << "type2=" << std::hex << type2 << std::dec << ",";
     if (hSz>20) {
-      int sSz=(int) input->readULong(1);
+      auto sSz=static_cast<int>(input->readULong(1));
       if ((sSz%2)!=0 || 20+1+sSz>hSz) {
         f << "###sSz=" << sSz << ",";
         MWAW_DEBUG_MSG(("RagTime5StructManager::readTypeDefinitions: the string size seems bad\n"));
@@ -190,8 +197,12 @@ bool RagTime5StructManager::readTypeDefinitions(RagTime5Zone &zone)
       else {
         std::string name("");
         for (int c=0; c<sSz/2; ++c)
-          name+=(char) input->readULong(2);
+          name+=char(input->readULong(2));
         f << "name=" << name << ",";
+        if (type2!=0x14a9842) {
+          f << "###type2,";
+          MWAW_DEBUG_MSG(("RagTime5StructManager::readTypeDefinitions: find odd type2 with a string size\n"));
+        }
       }
     }
     if (input->tell()!=pos+4+hSz)
@@ -205,16 +216,13 @@ bool RagTime5StructManager::readTypeDefinitions(RagTime5Zone &zone)
       f.str("");
       f << "TypeDef-" << i << "[" << j << "]:";
       f << "type=" << std::hex << input->readULong(4) << std::dec << ","; // a big number
-      val=(int) input->readULong(1); // 0 or small val
-      if (val) f << "fl0=" << std::hex << val << std::dec << ",";
-      val=(int) input->readULong(2); // small val
-      if (val) f << "f0=" << std::hex << val << std::dec << ",";
-      for (int k=0; k<3; ++k) {
-        val=(int) input->readULong(1);
-        if (val) f << "fl" << k+1 << "=" << std::hex << val << std::dec << ",";
+      f << "type2=" << std::hex << input->readULong(4) << std::dec << ","; // a big number
+      for (int k=0; k<2; ++k) {
+        val=static_cast<int>(input->readULong(1));
+        if (val) f << "fl" << k << "=" << std::hex << val << std::dec << ",";
       }
-      val=(int) input->readLong(2); // small val
-      if (val) f << "f1=" << val << ",";
+      val=static_cast<int>(input->readLong(2));
+      if (val) f << "f0=" << val << ",";
       ascFile.addPos(pos);
       ascFile.addNote(f.str().c_str());
       input->seek(pos+12, librevenge::RVNG_SEEK_SET);
@@ -242,7 +250,7 @@ bool RagTime5StructManager::readUnicodeString(MWAWInputStreamPtr input, long end
   length/=2;
   int lEndian=0, hEndian=0; // for checking if little/big endian is set correctly
   for (long i=0; i<length; ++i) {
-    uint32_t c=(uint32_t) input->readULong(2);
+    auto c=static_cast<uint32_t>(input->readULong(2));
     if ((c&0xFF00)==0) ++hEndian;
     else if ((c&0xFF)==0) ++lEndian;
     if (c!=0)
@@ -263,7 +271,7 @@ bool RagTime5StructManager::readDataIdList(MWAWInputStreamPtr input, int n, std:
   listIds.clear();
   long pos=input->tell();
   for (int i=0; i<n; ++i) {
-    int val=(int) MWAWInputStream::readULong(input->input().get(), 2, 0, false);
+    int val=static_cast<int>(MWAWInputStream::readULong(input->input().get(), 2, 0, false));
     if (val==0) {
       listIds.push_back(0);
       input->seek(2, librevenge::RVNG_SEEK_CUR);
@@ -274,7 +282,7 @@ bool RagTime5StructManager::readDataIdList(MWAWInputStreamPtr input, int n, std:
       input->seek(pos+4*n, librevenge::RVNG_SEEK_SET);
       return false;
     }
-    listIds.push_back((int) MWAWInputStream::readULong(input->input().get(), 2, 0, false));
+    listIds.push_back(static_cast<int>(MWAWInputStream::readULong(input->input().get(), 2, 0, false)));
   }
   return true;
 }
@@ -288,13 +296,13 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     MWAW_DEBUG_MSG(("RagTime5StructManager::readField: the zone seems too short\n"));
     return false;
   }
-  long type=(long) input->readULong(4);
+  auto type=long(input->readULong(4));
   if ((type>>16)==0) {
     input->seek(debPos, librevenge::RVNG_SEEK_SET);
     return false;
   }
   field.m_fileType=type;
-  bool complex=(int) input->readULong(1)==0xc0;
+  bool complex=static_cast<int>(input->readULong(1))==0xc0;
   input->seek(-1, librevenge::RVNG_SEEK_CUR);
   if (fSz<=0) {
     if (!readCompressedLong(input, endPos, fSz) || fSz<=0 || input->tell()+fSz>endPos) {
@@ -307,7 +315,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     fSz-=4;
   long debDataPos=input->tell();
   long endDataPos=debDataPos+fSz;
-  switch (type) {
+  switch (static_cast<unsigned long>(type)) {
   case 0x360c0:
   case 0x368c0:
     if (fSz!=1) {
@@ -318,7 +326,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     field.m_type=Field::T_Bool;
 
     field.m_name="bool";
-    field.m_longValue[0]=(long) input->readLong(1);
+    field.m_longValue[0]=long(input->readLong(1));
     return true;
 
   case 0x328c0:
@@ -329,7 +337,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     }
     field.m_type=Field::T_Long;
     field.m_name="bInt";
-    field.m_longValue[0]=(long) input->readLong(1);
+    field.m_longValue[0]=long(input->readLong(1));
     return true;
 
   case 0x3c057: // small int 3-9: not in typedef
@@ -347,7 +355,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     }
     field.m_type=Field::T_Long;
     field.m_name="int";
-    field.m_longValue[0]=(long) input->readLong(2);
+    field.m_longValue[0]=long(input->readLong(2));
     return true;
   case 0x34080:
   case 0xcf817: // bigger int dataId?: not in typedef
@@ -358,7 +366,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     }
     field.m_type=Field::T_Long;
     field.m_name="uint";
-    field.m_longValue[0]=(long) input->readULong(2);
+    field.m_longValue[0]=long(input->readULong(2));
     return true;
   case 0xb6000: // color percent
   case 0x1493800: // checkme double(as int)
@@ -417,8 +425,8 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     }
     field.m_type=Field::T_2Long;
     field.m_name="2xint";
-    field.m_longValue[0]=(long) input->readLong(2);
-    field.m_longValue[1]=(long) input->readLong(2);
+    field.m_longValue[0]=long(input->readLong(2));
+    field.m_longValue[1]=long(input->readLong(2));
     return true;
   case 0x7d01a:
   case 0xc8042: { // unicode
@@ -429,11 +437,11 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     }
     field.m_type=Field::T_Unicode;
     field.m_name="unicode";
-    int val=(int) input->readULong(2);
+    auto val=static_cast<int>(input->readULong(2));
     if ((val&0xF0FF)==0) {
       if ((val>>8)>2) f << "f1=" << (val>>8);
       for (int i=2; i<fSz; ++i)
-        libmwaw::appendUnicode((uint32_t) input->readULong(1), field.m_string);
+        libmwaw::appendUnicode(static_cast<uint32_t>(input->readULong(1)), field.m_string);
     }
     else {
       input->seek(debDataPos, librevenge::RVNG_SEEK_SET);
@@ -454,16 +462,16 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     }
     field.m_type=Field::T_Unicode;
     field.m_name="int+unicode";
-    int val=(int) input->readULong(2);
+    auto val=static_cast<int>(input->readULong(2));
     if (val==0xFF00 || val==1) {
       f << "multistring,";
-      val=(int) input->readULong(2);
+      val=static_cast<int>(input->readULong(2));
     }
     if ((val&0xF0FF)==0) {
       if ((val>>8)>2) f << "f1=" << (val>>8);
       fSz=int(endDataPos-input->tell());
       for (int i=0; i<fSz; ++i) {
-        uint32_t c=(uint32_t) input->readULong(1);
+        auto c=static_cast<uint32_t>(input->readULong(1));
         if (c)
           libmwaw::appendUnicode(c, field.m_string);
         else
@@ -488,7 +496,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     }
     field.m_type=Field::T_LongDouble;
     field.m_name="interline";
-    field.m_longValue[0]=(int) input->readLong(2);
+    field.m_longValue[0]=static_cast<int>(input->readLong(2));
     field.m_doubleValue=double(input->readLong(4))/65536.;
     return true;
   }
@@ -501,7 +509,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     field.m_type=Field::T_LongDouble;
     field.m_name="floatxint";
     field.m_doubleValue=double(input->readLong(4))/65536.;
-    field.m_longValue[0]=(int) input->readLong(2);
+    field.m_longValue[0]=static_cast<int>(input->readLong(2));
     return true;
   }
   case 0x74040: {
@@ -525,12 +533,12 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     }
     field.m_type=Field::T_TabList;
     field.m_name="tab";
-    int N=int(fSz/8);
+    auto N=int(fSz/8);
     for (int i=0; i<N; ++i) {
       TabStop tab;
       tab.m_position=float(input->readLong(4))/65536.f;
-      tab.m_type=(int) input->readLong(2);
-      tab.m_leaderChar=(uint16_t) input->readULong(2);
+      tab.m_type=static_cast<int>(input->readLong(2));
+      tab.m_leaderChar=static_cast<uint16_t>(input->readULong(2));
       field.m_tabList.push_back(tab);
     }
     return true;
@@ -560,7 +568,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     field.m_entry.setBegin(input->tell());
     field.m_entry.setEnd(endDataPos);
     for (long i=0; i<3; ++i) { // 1|3,1,1
-      int val=(int) input->readLong(2);
+      auto val=static_cast<int>(input->readLong(2));
       if (val) f << val << ":";
       else f << "_:";
     }
@@ -587,7 +595,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
       if (i==0) f << "x";
       else f << ",";
     }
-    int val=(int) input->readLong(2);
+    auto val=static_cast<int>(input->readLong(2));
     if (val!=0x100) f << val << ":";
     field.m_extra=f.str();
     return true;
@@ -600,16 +608,15 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     }
     field.m_type=Field::T_Color;
     field.m_name="rgba";
-    field.m_longValue[0]=(long) input->readLong(2); // id or numUsed
+    field.m_longValue[0]=long(input->readLong(2)); // id or numUsed
     if (field.m_longValue[0]==50) {
-      field.m_longValue[1]=(long) input->readULong(2);
+      field.m_longValue[1]=long(input->readULong(2));
       field.m_color=MWAWColor(255,255,255);
       input->seek(endDataPos, librevenge::RVNG_SEEK_SET);
       return true;
     }
     unsigned char col[4];
-    for (long i=0; i<4; ++i) // rgba
-      col[i]=(unsigned char)(input->readULong(2)>>8);
+    for (auto &c : col) c=static_cast<unsigned char>(input->readULong(2)>>8); // rgba
     field.m_color=MWAWColor(col[0],col[1],col[2],col[3]);
     return true;
   }
@@ -622,7 +629,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     field.m_type=Field::T_Code;
     field.m_name="rsrcName";
     for (long i=0; i<4; ++i)
-      field.m_string.append((char) input->readULong(1));
+      field.m_string.append(char(input->readULong(1)));
     return true;
   case 0x31e040:
     // <!DOCTYPE plist PUBLIC "-//Apple Computer//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
@@ -634,7 +641,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     field.m_type=Field::T_String;
     field.m_name="printInfoX";
     for (long i=0; i<fSz && i<30; ++i)
-      field.m_string.append((char) input->readULong(1));
+      field.m_string.append(char(input->readULong(1)));
     field.m_string.append("...");
     input->seek(endDataPos, librevenge::RVNG_SEEK_SET);
     return true;
@@ -672,10 +679,10 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     field.m_entry.setEnd(endDataPos);
     // name in lohi ?
     for (int i=0; i<32; ++i) {
-      int c=(int)input->readULong(1);
-      c+=(int)(input->readULong(1)<<8);
+      auto c=static_cast<int>(input->readULong(1));
+      c+=static_cast<int>(input->readULong(1)<<8);
       if (c==0) break;
-      f << (char) c;
+      f << char(c);
     }
     f << "...";
     field.m_extra=f.str();
@@ -742,16 +749,16 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     field.m_entry.setEnd(endDataPos);
     f << "fls=[" << std::hex;
     for (long i=0; i<8; ++i) {
-      int val=(int) input->readLong(1);
+      auto val=static_cast<int>(input->readLong(1));
       if (val==1) f << "_,";
       else f << val << ",";
     }
     f << "],";
     f << "chars=[";
     for (long i=0; i<21; ++i) {
-      int val=(int) input->readULong(2);
+      auto val=static_cast<int>(input->readULong(2));
       if (!val) f << "_,";
-      else if (val<128) f << (char) val << ",";
+      else if (val<128) f << char(val) << ",";
       else f << std::hex << val << std::dec << ",";
     }
     f << "],";
@@ -780,21 +787,53 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
       f << "###border";
       break;
     }
-    int val=(int) input->readULong(2); // c000 or c1000
+    auto val=static_cast<int>(input->readULong(2)); // c000 or c1000
     if (val!=0xc000) f << "f0=" << std::hex << val << std::dec << ",";
     field.m_type=Field::T_LongList;
     field.m_name="border";
     field.m_numLongByData=3;
     fSz/=6;
     for (long i=0; i<fSz; ++i) {
-      field.m_longList.push_back((long) input->readLong(2)); // row?
-      field.m_longList.push_back((long) input->readLong(2)); // col?
-      field.m_longList.push_back((long) input->readULong(2)); // flags?
+      field.m_longList.push_back(long(input->readLong(2))); // row?
+      field.m_longList.push_back(long(input->readLong(2))); // col?
+      field.m_longList.push_back(long(input->readULong(2))); // flags?
+    }
+    field.m_extra=f.str();
+    return true;
+  }
+  case 0x64040: { // chart pref
+    if (fSz<3) {
+      MWAW_DEBUG_MSG(("RagTime5StructManager::readField: unexpected data fSz for chart pref\n"));
+      f << "###chart pref";
+      break;
+    }
+    field.m_type=Field::T_FieldList;
+    field.m_entry.setBegin(input->tell());
+    field.m_entry.setEnd(endDataPos);
+    for (int i=0; i<3; ++i) { // f2=8|9
+      auto val=static_cast<int>(input->readLong(1));
+      if (val) f << "f" << i << "=" << val << ",";
+    }
+    bool ok=true;
+    while (input->tell()<endDataPos) {
+      Field child;
+      long pos=input->tell();
+      if (!readField(input, endDataPos, ascFile, child)) {
+        ok=false;
+        input->seek(pos, librevenge::RVNG_SEEK_SET);
+        break;
+      }
+      field.m_fieldList.push_back(child);
+    }
+    if (!ok || input->tell() != endDataPos) {
+      MWAW_DEBUG_MSG(("RagTime5StructManager::readField: can not read some charr pref list data\n"));
+      f.str("");
+      f << "###pos=" << input->tell()-debPos;
+      input->seek(endDataPos, librevenge::RVNG_SEEK_SET);
     }
     field.m_extra=f.str();
     return true;
   }
-
   case 0xce017: { // unstructured: not in typedef
     if (fSz<5) {
       MWAW_DEBUG_MSG(("RagTime5StructManager::readField: unexpected data fSz for unstructured\n"));
@@ -808,7 +847,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     field.m_entry.setEnd(endDataPos);
     f << "data=" << std::hex;
     for (long i=0; i<fSz-4; ++i)
-      f << std::setfill('0') << std::setw(2) << (int) input->readULong(1);
+      f << std::setfill('0') << std::setw(2) << static_cast<int>(input->readULong(1));
     f << std::dec << ",";
     field.m_extra=f.str();
     return true;
@@ -824,7 +863,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     field.m_type=Field::T_LongList;
     field.m_name="longList";
     for (long i=0; i<fSz; ++i)
-      field.m_longList.push_back((long) input->readLong(4));
+      field.m_longList.push_back(long(input->readLong(4)));
     return true;
   }
   case 0x80045080: // child of 14741fa
@@ -838,9 +877,15 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     field.m_type=Field::T_LongList;
     field.m_name="intList";
     for (long i=0; i<fSz; ++i)
-      field.m_longList.push_back((long) input->readLong(2));
+      field.m_longList.push_back(long(input->readLong(2)));
     return true;
   }
+  case 0x154f017: // list of bytes
+    field.m_type=Field::T_LongList;
+    field.m_name="byteList";
+    for (long i=0; i<fSz; ++i)
+      field.m_longList.push_back(long(input->readLong(1)));
+    return true;
   case 0x35000: // checkme find also a string code here...
   case 0x35800: // unsure, ie small int
   case 0x3e800: // unsure, find with 000af040, 00049840 or 0004c040
@@ -851,7 +896,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
       break;
     }
     field.m_type=Field::T_Long;
-    field.m_longValue[0]=(long) input->readULong(4);
+    field.m_longValue[0]=long(input->readULong(4));
     return true;
   case 0xa4840:
     if (fSz!=8) {
@@ -861,12 +906,14 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     }
     field.m_type=Field::T_2Long;
     field.m_name="2xuint32";
-    for (long i=0; i<2; ++i)
-      field.m_longValue[i]=(long) input->readULong(4);
+    for (long &i : field.m_longValue)
+      i=long(input->readULong(4));
     return true;
 
   case 0x33000: // maybe one 2xint
   case 0x1671817:
+  case 0x16b492a: // in chart, dim[4byte], id, 0
+  case 0x16b5aea: // chart preference, always 0,0,id,0
   case 0x80033000:
     if ((fSz%4)!=0) {
       MWAW_DEBUG_MSG(("RagTime5StructManager::readField: unexpected data fSz for list of 2xint\n"));
@@ -878,7 +925,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     field.m_numLongByData=2;
     fSz/=2;
     for (long i=0; i<fSz; ++i)
-      field.m_longList.push_back((long) input->readLong(2));
+      field.m_longList.push_back(long(input->readLong(2)));
     return true;
   case 0x81452040: {
     if (fSz!=8) {
@@ -1009,6 +1056,9 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
   case 0x148983a: // with type=0074040
   case 0x148985a: // with type=1495800
 
+  case 0x16c1825: // chart pref with type=0042040 CHECKME
+  case 0x16d5840: // chart main pref
+
   // docinfo zone
   case 0x1f7817:
   case 0x1f7827:
@@ -1079,11 +1129,10 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     }
     field.m_type=Field::T_CondColor;
     field.m_name="condition";
-    field.m_longValue[0]=(long) input->readLong(2); // numUsed ?
-    field.m_longValue[1]=(long) input->readLong(2); // formula id ?
+    field.m_longValue[0]=long(input->readLong(2)); // numUsed ?
+    field.m_longValue[1]=long(input->readLong(2)); // formula id ?
     unsigned char col[4];
-    for (long i=0; i<4; ++i) // rgba
-      col[i]=(unsigned char)(input->readULong(2)>>8);
+    for (auto &c : col) c=static_cast<unsigned char>(input->readULong(2)>>8); // rgba
     field.m_color=MWAWColor(col[0],col[1],col[2],col[3]);
     return true;
   }
@@ -1094,26 +1143,26 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
       f << "###func[def],";
       break;
     }
-    int val=(int) input->readLong(1); // always 0?
+    auto val=static_cast<int>(input->readLong(1)); // always 0?
     if (val) f << "f1=" << val << ",";
-    int N=(int) input->readULong(1);
+    auto N=static_cast<int>(input->readULong(1));
     if (6+N!=fSz) {
       MWAW_DEBUG_MSG(("RagTime5StructManager::readField: unexpected field N for functions def list\n"));
       f << "###func[def],N=" << N << ",";
       break;
     }
     for (int i=0; i<3; ++i) { // 0,-1|0|1,0
-      val=(int) input->readLong(1);
+      val=static_cast<int>(input->readLong(1));
       if (!val) continue;
       f << "f" << i+2 << "=" << val << ",";
     }
-    val=(int) input->readULong(1); //0|40|c0
+    val=static_cast<int>(input->readULong(1)); //0|40|c0
     if (val) f << "f5=" << std::hex << val << std::dec << ",";
     // list of [0|1|20]*
     field.m_type=Field::T_LongList;
     field.m_name="func[def]";
     for (int i=0; i<N; ++i)
-      field.m_longList.push_back((int) input->readULong(1));
+      field.m_longList.push_back(static_cast<int>(input->readULong(1)));
     field.m_extra=f.str();
     return true;
   }
@@ -1183,7 +1232,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
       break;
     }
     for (int i=0; i<3; ++i) { // f1=0|-1, f2=small number, other 0
-      int val=(int) input->readLong(2);
+      auto val=static_cast<int>(input->readLong(2));
       if (val) f << "f" << i+1 << "=" << val << ",";
     }
     field.m_type=Field::T_FieldList;
@@ -1216,16 +1265,16 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     }
     int val;
     for (int i=0; i<2; ++i) { // always 0?
-      val=(int) input->readULong(2);
+      val=static_cast<int>(input->readULong(2));
       if (val) f << "f" << i+1 << "=" << val << ",";
     }
-    int N=(int) input->readULong(2);
-    val=(int) input->readULong(2); // always 20 ?
+    auto N=static_cast<int>(input->readULong(2));
+    val=static_cast<int>(input->readULong(2)); // always 20 ?
     if (val!=20) f << "f3=" << val << ",";
-    val=(int) input->readULong(2); // always 0 ?
+    val=static_cast<int>(input->readULong(2)); // always 0 ?
     if (val) f << "f4=" << val << ",";
     field.m_type=Field::T_FieldList;
-    field.m_name="list[day/month]";
+    field.m_name="container[list]"; // can be day/month, ...
     bool ok=true;
     for (int i=0; i<N; ++i) {
       Field child;
@@ -1238,7 +1287,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
       field.m_fieldList.push_back(child);
     }
     if (!ok || input->tell() != endDataPos) {
-      MWAW_DEBUG_MSG(("RagTime5StructManager::readField: can not read some day/month list data\n"));
+      MWAW_DEBUG_MSG(("RagTime5StructManager::readField: can not read some container list data\n"));
       f.str("");
       f << "###pos=" << input->tell()-debPos;
       input->seek(endDataPos, librevenge::RVNG_SEEK_SET);
@@ -1257,7 +1306,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     field.m_name="3unknList";
     field.m_numLongByData=3;
     for (long i=0; i<fSz; ++i)
-      field.m_longList.push_back((long) input->readLong(2));
+      field.m_longList.push_back(long(input->readLong(2)));
     return true;
   }
   default:
@@ -1268,7 +1317,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
   if (!complex) {
     static bool first=true;
     if (first) {
-      MWAW_DEBUG_MSG(("RagTime5StructManager::readField: find some unexpected data type=%lx, ...\n", (unsigned long) type));
+      MWAW_DEBUG_MSG(("RagTime5StructManager::readField: find some unexpected data type=%lx, ...\n", static_cast<unsigned long>(type)));
       first=false;
     }
     field.m_name="#unknType";
@@ -1307,8 +1356,7 @@ bool RagTime5StructManager::readField(MWAWInputStreamPtr input, long endPos, lib
     field.m_name="unknLstPict";
     break;
   default:
-    // find also 16c1825 with 00042040000000000001001400000006404003000008 : a list of 42040 ?
-    MWAW_DEBUG_MSG(("RagTime5StructManager::readField: unexpected list type=%lx\n", (unsigned long) type));
+    MWAW_DEBUG_MSG(("RagTime5StructManager::readField: unexpected list type=%lx\n", static_cast<unsigned long>(type)));
     field.m_name="#unknList";
     break;
   }
@@ -1394,8 +1442,8 @@ std::ostream &operator<<(std::ostream &o, RagTime5StructManager::Field const &fi
   case RagTime5StructManager::Field::T_FieldList:
     if (!field.m_fieldList.empty()) {
       o << "=[";
-      for (size_t i=0; i< field.m_fieldList.size(); ++i)
-        o << "[" << field.m_fieldList[i] << "],";
+      for (auto val : field.m_fieldList)
+        o << "[" << val << "],";
       o << "]";
     }
     o << ",";
@@ -1403,8 +1451,8 @@ std::ostream &operator<<(std::ostream &o, RagTime5StructManager::Field const &fi
   case RagTime5StructManager::Field::T_DoubleList:
     if (!field.m_doubleList.empty()) {
       o << "=[";
-      for (size_t i=0; i<field.m_doubleList.size(); ++i)
-        o << field.m_doubleList[i] << ",";
+      for (auto const &val : field.m_doubleList)
+        o << val << ",";
       o << "],";
     }
     break;
@@ -1419,7 +1467,7 @@ std::ostream &operator<<(std::ostream &o, RagTime5StructManager::Field const &fi
             o << "_";
           else if (val>-1000 && val <1000)
             o << val;
-          else if (val==(long) 0x80000000)
+          else if (val==long(0x80000000))
             o << "inf";
           // find sometime 0x3e7f0001
           else
@@ -1434,13 +1482,15 @@ std::ostream &operator<<(std::ostream &o, RagTime5StructManager::Field const &fi
   case RagTime5StructManager::Field::T_TabList:
     if (!field.m_tabList.empty()) {
       o << "=[";
-      for (size_t i=0; i<field.m_tabList.size(); ++i)
-        o << field.m_tabList[i] << ",";
+      for (auto const &tab : field.m_tabList)
+        o << tab << ",";
       o << "],";
     }
     break;
   case RagTime5StructManager::Field::T_Unknown:
+#if !defined(__clang__)
   default:
+#endif
     o << "[###unkn],";
     break;
   }
@@ -1456,8 +1506,7 @@ bool RagTime5StructManager::GObjPropFieldParser::parseField(Field &field, RagTim
   if (field.m_type==Field::T_FieldList) {
     switch (field.m_fileType) {
     case 0x6615a:
-      for (size_t i=0; i<field.m_fieldList.size(); ++i) {
-        RagTime5StructManager::Field const &child=field.m_fieldList[i];
+      for (auto const &child : field.m_fieldList) {
         if (child.m_type==Field::T_2Long && child.m_fileType==0x8c000) {
           f << "dim=" << child.m_longValue[0] << "x" << child.m_longValue[1] << ",";
           continue;
@@ -1467,8 +1516,7 @@ bool RagTime5StructManager::GObjPropFieldParser::parseField(Field &field, RagTim
       }
       break;
     case 0x6616a:
-      for (size_t i=0; i<field.m_fieldList.size(); ++i) {
-        RagTime5StructManager::Field const &child=field.m_fieldList[i];
+      for (auto const &child : field.m_fieldList) {
         if (child.m_type==Field::T_Unstructured && child.m_fileType==0x79040) {
           f << "data1=" << child << ",";
           continue;
@@ -1478,8 +1526,7 @@ bool RagTime5StructManager::GObjPropFieldParser::parseField(Field &field, RagTim
       }
       break;
     case 0x6617a: // 0[13]0[01]
-      for (size_t i=0; i<field.m_fieldList.size(); ++i) {
-        RagTime5StructManager::Field const &child=field.m_fieldList[i];
+      for (auto const &child : field.m_fieldList) {
         if (child.m_type==Field::T_Long && child.m_fileType==0x34080) {
           f << "data2=" << std::hex << child.m_longValue[0] << std::dec << ",";
           continue;
@@ -1489,9 +1536,8 @@ bool RagTime5StructManager::GObjPropFieldParser::parseField(Field &field, RagTim
       }
       break;
     case 0x6619a:
-      for (size_t i=0; i<field.m_fieldList.size(); ++i) {
-        RagTime5StructManager::Field const &child=field.m_fieldList[i];
-        if (child.m_type==Field::T_ZoneId && (unsigned long)(child.m_fileType)==0x81452040) {
+      for (auto const &child : field.m_fieldList) {
+        if (child.m_type==Field::T_ZoneId && static_cast<unsigned long>(child.m_fileType)==0x81452040) {
           f << "cluster[id]=data" << child.m_longValue[0] << "A,";
           continue;
         }
@@ -1500,8 +1546,7 @@ bool RagTime5StructManager::GObjPropFieldParser::parseField(Field &field, RagTim
       }
       break;
     case 0xfd827: // rare with 0
-      for (size_t i=0; i<field.m_fieldList.size(); ++i) {
-        RagTime5StructManager::Field const &child=field.m_fieldList[i];
+      for (auto const &child : field.m_fieldList) {
         if (child.m_type==Field::T_Long && child.m_fileType==0x3b880) {
           f << "data3=" << child.m_longValue[0] << ",";
           continue;
@@ -1511,11 +1556,10 @@ bool RagTime5StructManager::GObjPropFieldParser::parseField(Field &field, RagTim
       }
       break;
     case 0x10581a: // 1,_ or _,1 or 4000,1
-      for (size_t i=0; i<field.m_fieldList.size(); ++i) {
-        RagTime5StructManager::Field const &child=field.m_fieldList[i];
+      for (auto const &child : field.m_fieldList) {
         if (child.m_type==Field::T_LongList && child.m_fileType==0x33000) {
           f << "long[list]=[";
-          for (size_t j=0; j<child.m_longList.size(); ++j) f << std::hex << child.m_longList[j] << std::dec << ",";
+          for (auto val : child.m_longList) f << std::hex << val << std::dec << ",";
           f << "],";
           continue;
         }
@@ -1524,11 +1568,10 @@ bool RagTime5StructManager::GObjPropFieldParser::parseField(Field &field, RagTim
       }
       break;
     case 0x111817: // margin in %
-      for (size_t i=0; i<field.m_fieldList.size(); ++i) {
-        RagTime5StructManager::Field const &child=field.m_fieldList[i];
+      for (auto const &child : field.m_fieldList) {
         if (child.m_type==Field::T_DoubleList && child.m_fileType==0x112040 && child.m_doubleList.size()==4) {
-          f << "margins=" << MWAWBox2f(MWAWVec2f((float)child.m_doubleList[0],(float)child.m_doubleList[1]),
-                                       MWAWVec2f((float)child.m_doubleList[2],(float)child.m_doubleList[3])) << ",";
+          f << "margins=" << MWAWBox2f(MWAWVec2f(float(child.m_doubleList[0]),float(child.m_doubleList[1])),
+                                       MWAWVec2f(float(child.m_doubleList[2]),float(child.m_doubleList[3]))) << ",";
           continue;
         }
         MWAW_DEBUG_MSG(("RagTime5StructManager::GObjPropFieldParser::parseField: find margins field\n"));
@@ -1536,8 +1579,7 @@ bool RagTime5StructManager::GObjPropFieldParser::parseField(Field &field, RagTim
       }
       break;
     case 0x111827: // always 0,0
-      for (size_t i=0; i<field.m_fieldList.size(); ++i) {
-        RagTime5StructManager::Field const &child=field.m_fieldList[i];
+      for (auto const &child : field.m_fieldList) {
         if (child.m_type==Field::T_2Long && child.m_fileType==0x34800) {
           f << "unknPos=" << child.m_longValue[0] << "x" << child.m_longValue[1] << ",";
           continue;
@@ -1547,11 +1589,10 @@ bool RagTime5StructManager::GObjPropFieldParser::parseField(Field &field, RagTim
       }
       break;
     case 0x1467837: // always 0,0
-      for (size_t i=0; i<field.m_fieldList.size(); ++i) {
-        RagTime5StructManager::Field const &child=field.m_fieldList[i];
+      for (auto const &child : field.m_fieldList) {
         if (child.m_type==Field::T_DoubleList && child.m_fileType==0x74040) {
           f << "float[list]=[";
-          for (size_t j=0; j<child.m_doubleList.size(); ++j) f << child.m_doubleList[j] << ",";
+          for (auto const &val : child.m_doubleList) f << val << ",";
           f << "],";
           continue;
         }
@@ -1561,8 +1602,7 @@ bool RagTime5StructManager::GObjPropFieldParser::parseField(Field &field, RagTim
       break;
     case 0x146789a: // 1-2
     case 0x14678aa: // 1-2
-      for (size_t i=0; i<field.m_fieldList.size(); ++i) {
-        RagTime5StructManager::Field const &child=field.m_fieldList[i];
+      for (auto const &child : field.m_fieldList) {
         if (child.m_type==Field::T_Long && child.m_fileType==0x149e080) {
           f << "d" << ((field.m_fileType>>4)&0xf) << "=" << std::hex << child.m_longValue[0] << std::dec << ",";
           continue;
@@ -1587,6 +1627,10 @@ bool RagTime5StructManager::GObjPropFieldParser::parseField(Field &field, RagTim
 ////////////////////////////////////////////////////////////
 // zone function
 ////////////////////////////////////////////////////////////
+RagTime5Zone::~RagTime5Zone()
+{
+}
+
 void RagTime5Zone::createAsciiFile()
 {
   if (m_asciiName.empty()) {
