@@ -58,7 +58,13 @@ namespace ZWrtParserInternal
 //! Internal: the state of a ZWrtParser
 struct State {
   //! constructor
-  State() : m_actPage(0), m_numPages(0), m_headerUsed(true), m_footerUsed(true), m_headerHeight(0), m_footerHeight(0)
+  State()
+    : m_actPage(0)
+    , m_numPages(0)
+    , m_headerUsed(true)
+    , m_footerUsed(true)
+    , m_headerHeight(0)
+    , m_footerHeight(0)
   {
   }
 
@@ -74,33 +80,30 @@ struct State {
 
 ////////////////////////////////////////
 //! Internal: the subdocument of a ZWrtParser
-class SubDocument : public MWAWSubDocument
+class SubDocument final : public MWAWSubDocument
 {
 public:
-  SubDocument(ZWrtParser &pars, MWAWInputStreamPtr input, bool header) :
-    MWAWSubDocument(&pars, input, MWAWEntry()), m_isHeader(header) {}
+  SubDocument(ZWrtParser &pars, MWAWInputStreamPtr const &input, bool header)
+    : MWAWSubDocument(&pars, input, MWAWEntry())
+    , m_isHeader(header)
+  {
+  }
 
   //! destructor
-  virtual ~SubDocument() {}
+  ~SubDocument() final {}
 
   //! operator!=
-  virtual bool operator!=(MWAWSubDocument const &doc) const
+  bool operator!=(MWAWSubDocument const &doc) const final
   {
     if (MWAWSubDocument::operator!=(doc)) return true;
-    SubDocument const *sDoc = dynamic_cast<SubDocument const *>(&doc);
+    auto const *sDoc = dynamic_cast<SubDocument const *>(&doc);
     if (!sDoc) return true;
     if (m_isHeader != sDoc->m_isHeader) return true;
     return false;
   }
 
-  //! operator!==
-  virtual bool operator==(MWAWSubDocument const &doc) const
-  {
-    return !operator!=(doc);
-  }
-
   //! the parser function
-  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type);
+  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type) final;
 
 protected:
   //! true if we need to send the parser
@@ -113,7 +116,7 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*ty
     MWAW_DEBUG_MSG(("ZWrtParserInternal::SubDocument::parse: no listener\n"));
     return;
   }
-  ZWrtParser *parser=dynamic_cast<ZWrtParser *>(m_parser);
+  auto *parser=dynamic_cast<ZWrtParser *>(m_parser);
   if (!parser) {
     MWAW_DEBUG_MSG(("ZWrtParserInternal::SubDocument::parse: no parser\n"));
     return;
@@ -127,8 +130,10 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*ty
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-ZWrtParser::ZWrtParser(MWAWInputStreamPtr input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header) :
-  MWAWTextParser(input, rsrcParser, header), m_state(), m_textParser()
+ZWrtParser::ZWrtParser(MWAWInputStreamPtr const &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
+  : MWAWTextParser(input, rsrcParser, header)
+  , m_state()
+  , m_textParser()
 {
   init();
 }
@@ -202,10 +207,10 @@ void ZWrtParser::newPage(int number)
 ////////////////////////////////////////////////////////////
 void ZWrtParser::parse(librevenge::RVNGTextInterface *docInterface)
 {
-  if (!getInput().get() || !getRSRCParser() || !checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !getRSRCParser() || !checkHeader(nullptr))  throw(libmwaw::ParseException());
   bool ok = false;
   try {
-    checkHeader(0L);
+    checkHeader(nullptr);
     ok = createZones();
     if (ok) {
       createDocument(docInterface);
@@ -275,13 +280,12 @@ bool ZWrtParser::createZones()
     MWAW_DEBUG_MSG(("ZWrtParser::createZones: can not find the entry map\n"));
     return false;
   }
-  std::multimap<std::string, MWAWEntry> &entryMap = rsrcParser->getEntriesMap();
-  std::multimap<std::string, MWAWEntry>::iterator it;
+  auto &entryMap = rsrcParser->getEntriesMap();
 
   // the 128 zones
   char const *(zNames[]) = {"BBAR", "HTML", "PRIN", "RANG", "WPOS", "PGPT"};
   for (int z = 0; z < 6; z++) {
-    it = entryMap.lower_bound(zNames[z]);
+    auto it = entryMap.lower_bound(zNames[z]);
     while (it != entryMap.end()) {
       if (it->first != zNames[z])
         break;
@@ -318,7 +322,7 @@ bool ZWrtParser::createZones()
   // 1001 and following
   char const *(sNames[]) = {"CPOS", "SLEN"};
   for (int z = 0; z < 2; z++) {
-    it = entryMap.lower_bound(sNames[z]);
+    auto it = entryMap.lower_bound(sNames[z]);
     while (it != entryMap.end()) {
       if (it->first != sNames[z])
         break;
@@ -932,7 +936,7 @@ bool ZWField::getString(MWAWInputStreamPtr &input, std::string &str) const
     return true;
   input->seek(m_pos.begin(), librevenge::RVNG_SEEK_SET);
   while (!input->isEnd() && input->tell()!=m_pos.end()) {
-    char c=char(input->readULong(1));
+    auto c=char(input->readULong(1));
     if (c==0) {
       MWAW_DEBUG_MSG(("ZWField::getString::readFieldString: find a zero entry\n"));
       str += "##[0]";
@@ -951,7 +955,7 @@ bool ZWField::getDebugString(MWAWInputStreamPtr &input, std::string &str) const
   input->seek(m_pos.begin(), librevenge::RVNG_SEEK_SET);
   std::stringstream ss;
   while (!input->isEnd() && input->tell()!=m_pos.end()) {
-    char c=char(input->readULong(1));
+    auto c=char(input->readULong(1));
     if (static_cast<unsigned char>(c)<=0x1f && c!= 0x9)
       ss << "##[" << std::hex << int(c) << std::dec << "]";
     else
